# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cluster_manager.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cluster_manager.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63luster_manager.proto\"\x19\n\nStopPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x03\"\x1a\n\x0b\x43heckPidMsg\x12\x0b\n\x03pid\x18\x01 \x01(\x03\"S\n\x13StartSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12StopSparkServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StartSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13StopSparkServersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"Y\n\x1dGetExecutionTimeSeriesDataMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x0f\n\x07minutes\x18\x03 \x01(\x03\"\xfe\x12\n\x1d\x45mulationMetricsTimeSeriesDTO\x12\x33\n\x0e\x63lient_metrics\x18\x01 \x03(\x0b\x32\x1b.ClientPopulationMetricsDTO\x12\x30\n\x17\x61ggregated_docker_stats\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\x12+\n\x11\x64ocker_host_stats\x18\x03 \x03(\x0b\x32\x10.DockerStatsDict\x12&\n\x0chost_metrics\x18\x04 \x03(\x0b\x32\x10.HostMetricsDict\x12\x34\n\x17\x61ggregated_host_metrics\x18\x05 \x03(\x0b\x32\x13.HostMetricsDataDTO\x12\x35\n\x10\x64\x65\x66\x65nder_actions\x18\x06 \x03(\x0b\x32\x1b.EmulationDefenderActionDTO\x12\x35\n\x10\x61ttacker_actions\x18\x07 \x03(\x0b\x32\x1b.EmulationAttackerActionDTO\x12\x38\n\x15\x61gg_snort_ids_metrics\x18\x08 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\x12\x14\n\x0c\x65mulation_id\x18\t \x01(\x03\x12=\n\x19ossec_host_alert_counters\x18\n \x03(\x0b\x32\x1a.OSSECIdsAlertCountersDict\x12G\n$aggregated_ossec_host_alert_counters\x18\x0b \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\x12.\n\x13openflow_flow_stats\x18\x0c \x03(\x0b\x32\x11.FlowStatisticDTO\x12.\n\x13openflow_port_stats\x18\r \x03(\x0b\x32\x11.PortStatisticDTO\x12\x35\n\x17\x61vg_openflow_flow_stats\x18\x0e \x03(\x0b\x32\x14.AvgFlowStatisticDTO\x12\x35\n\x17\x61vg_openflow_port_stats\x18\x0f \x03(\x0b\x32\x14.AvgPortStatisticDTO\x12<\n openflow_flow_metrics_per_switch\x18\x10 \x03(\x0b\x32\x12.FlowStatisticDict\x12<\n openflow_port_metrics_per_switch\x18\x11 \x03(\x0b\x32\x12.PortStatisticDict\x12\x43\n$openflow_flow_avg_metrics_per_switch\x18\x12 \x03(\x0b\x32\x15.AvgFlowStatisticDict\x12\x43\n$openflow_port_avg_metrics_per_switch\x18\x13 \x03(\x0b\x32\x15.AvgPortStatisticDict\x12\x43\n$agg_openflow_flow_metrics_per_switch\x18\x14 \x03(\x0b\x32\x15.AggFlowStatisticDict\x12\x35\n\x17\x61gg_openflow_flow_stats\x18\x15 \x03(\x0b\x32\x14.AggFlowStatisticDTO\x12<\n\x1a\x61gg_snort_ids_rule_metrics\x18\x16 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\x12:\n\x14snort_ids_ip_metrics\x18\x17 \x03(\x0b\x32\x1c.SnortIdsIpAlertCountersDict\x12=\n\x1asnort_rule_metrics_per_ids\x18\x18 \x03(\x0b\x32\x19.SnortIdsRuleCountersDict\x12?\n\x1bsnort_alert_metrics_per_ids\x18\x19 \x03(\x0b\x32\x1a.SnortIdsAlertCountersDict\x12\x39\n\x17\x66ive_g_core_amf_metrics\x18\x1a \x03(\x0b\x32\x18.FiveGCoreAMFMetricsDict\x12\x39\n\x17\x66ive_g_core_hss_metrics\x18\x1b \x03(\x0b\x32\x18.FiveGCoreHSSMetricsDict\x12\x39\n\x17\x66ive_g_core_mme_metrics\x18\x1c \x03(\x0b\x32\x18.FiveGCoreMMEMetricsDict\x12\x39\n\x17\x66ive_g_core_pcf_metrics\x18\x1d \x03(\x0b\x32\x18.FiveGCorePCFMetricsDict\x12;\n\x18\x66ive_g_core_pcrf_metrics\x18\x1e \x03(\x0b\x32\x19.FiveGCorePCRFMetricsDict\x12\x39\n\x17\x66ive_g_core_smf_metrics\x18\x1f \x03(\x0b\x32\x18.FiveGCoreSMFMetricsDict\x12\x39\n\x17\x66ive_g_core_upf_metrics\x18  \x03(\x0b\x32\x18.FiveGCoreUPFMetricsDict\x12Q\n$five_g_cu_app_resource_usage_metrics\x18! \x03(\x0b\x32#.FiveGCUAppResourceUsageMetricsDict\x12\x44\n\x1d\x66ive_g_cu_buffer_pool_metrics\x18\" \x03(\x0b\x32\x1d.FiveGCUBufferPoolMetricsDict\x12\x33\n\x14\x66ive_g_cu_cp_metrics\x18# \x03(\x0b\x32\x15.FiveGCUCPMetricsDict\x12Q\n$five_g_du_app_resource_usage_metrics\x18$ \x03(\x0b\x32#.FiveGDUAppResourceUsageMetricsDict\x12\x44\n\x1d\x66ive_g_du_buffer_pool_metrics\x18% \x03(\x0b\x32\x1d.FiveGDUBufferPoolMetricsDict\x12\x37\n\x16\x66ive_g_du_cell_metrics\x18& \x03(\x0b\x32\x17.FiveGDUCellMetricsDict\x12\x35\n\x15\x66ive_g_du_low_metrics\x18\' \x03(\x0b\x32\x16.FiveGDULowMetricsDict\x12.\n\x11\x66ive_g_du_metrics\x18( \x03(\x0b\x32\x13.FiveGDUMetricsDict\x12\x35\n\x15\x66ive_g_du_rlc_metrics\x18) \x03(\x0b\x32\x16.FiveGDURLCMetricsDict\"G\n\x14\x41vgPortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgPortStatisticDTO\"G\n\x14\x41ggFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AggFlowStatisticDTO\"G\n\x14\x41vgFlowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.AvgFlowStatisticDTO\"A\n\x11PortStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.PortStatisticDTO\"A\n\x11\x46lowStatisticDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x11.FlowStatisticDTO\"Q\n\x19OSSECIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.OSSECIdsAlertCountersDTO\"A\n\x0fHostMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x13.HostMetricsDataDTO\"=\n\x0f\x44ockerStatsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x0f.DockerStatsDTO\"\xbc\x04\n\x13\x41vgPortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\"\n\x1atotal_num_received_packets\x18\x03 \x01(\x03\x12 \n\x18total_num_received_bytes\x18\x04 \x01(\x03\x12!\n\x19total_num_received_errors\x18\x05 \x01(\x03\x12%\n\x1dtotal_num_transmitted_packets\x18\x06 \x01(\x03\x12#\n\x1btotal_num_transmitted_bytes\x18\x07 \x01(\x03\x12$\n\x1ctotal_num_transmitted_errors\x18\x08 \x01(\x03\x12\"\n\x1atotal_num_received_dropped\x18\t \x01(\x03\x12%\n\x1dtotal_num_transmitted_dropped\x18\n \x01(\x03\x12\'\n\x1ftotal_num_received_frame_errors\x18\x0b \x01(\x03\x12)\n!total_num_received_overrun_errors\x18\x0c \x01(\x03\x12%\n\x1dtotal_num_received_crc_errors\x18\r \x01(\x03\x12\x1c\n\x14total_num_collisions\x18\x0e \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x0f \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x10 \x01(\x03\"\x8f\x02\n\x13\x41vgFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12 \n\x18\x61vg_duration_nanoseconds\x18\x05 \x01(\x03\x12\x1c\n\x14\x61vg_duration_seconds\x18\x06 \x01(\x03\x12\x18\n\x10\x61vg_hard_timeout\x18\x07 \x01(\x03\x12\x18\n\x10\x61vg_idle_timeout\x18\x08 \x01(\x03\x12\x14\n\x0c\x61vg_priority\x18\t \x01(\x03\x12\x12\n\navg_cookie\x18\n \x01(\x03\"\x8a\x01\n\x13\x41ggFlowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x19\n\x11total_num_packets\x18\x03 \x01(\x03\x12\x17\n\x0ftotal_num_bytes\x18\x04 \x01(\x03\x12\x17\n\x0ftotal_num_flows\x18\x05 \x01(\x03\"\xf7\x03\n\x10PortStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x03\x12\x1c\n\x14num_received_packets\x18\x04 \x01(\x03\x12\x1a\n\x12num_received_bytes\x18\x05 \x01(\x03\x12\x1b\n\x13num_received_errors\x18\x06 \x01(\x03\x12\x1f\n\x17num_transmitted_packets\x18\x07 \x01(\x03\x12\x1d\n\x15num_transmitted_bytes\x18\x08 \x01(\x03\x12\x1e\n\x16num_transmitted_errors\x18\t \x01(\x03\x12\x1c\n\x14num_received_dropped\x18\n \x01(\x03\x12\x1f\n\x17num_transmitted_dropped\x18\x0b \x01(\x03\x12!\n\x19num_received_frame_errors\x18\x0c \x01(\x03\x12#\n\x1bnum_received_overrun_errors\x18\r \x01(\x03\x12\x1f\n\x17num_received_crc_errors\x18\x0e \x01(\x03\x12\x16\n\x0enum_collisions\x18\x0f \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x10 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\x11 \x01(\x03\"\xa4\x02\n\x10\x46lowStatisticDTO\x12\x11\n\ttimestamp\x18\x01 \x01(\x02\x12\x13\n\x0b\x64\x61tapath_id\x18\x02 \x01(\t\x12\x0f\n\x07in_port\x18\x03 \x01(\t\x12\x10\n\x08out_port\x18\x04 \x01(\t\x12\x17\n\x0f\x64st_mac_address\x18\x05 \x01(\t\x12\x13\n\x0bnum_packets\x18\x06 \x01(\x03\x12\x11\n\tnum_bytes\x18\x07 \x01(\x03\x12\x1c\n\x14\x64uration_nanoseconds\x18\x08 \x01(\x03\x12\x18\n\x10\x64uration_seconds\x18\t \x01(\x03\x12\x14\n\x0chard_timeout\x18\n \x01(\x03\x12\x14\n\x0cidle_timeout\x18\x0b \x01(\x03\x12\x10\n\x08priority\x18\x0c \x01(\x03\x12\x0e\n\x06\x63ookie\x18\r \x01(\x03\"\xc5\x01\n\x18OSSECIdsAlertCountersDTO\x12\x14\n\x0clevel_alerts\x18\x01 \x03(\x03\x12\x14\n\x0cgroup_alerts\x18\x02 \x03(\x03\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x03\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x03\x12\x14\n\x0ctotal_alerts\x18\x05 \x01(\x03\x12 \n\x18\x61lerts_weighted_by_level\x18\x06 \x01(\x02\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xb5\x01\n\x18SnortIdsAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x03\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x03\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x03\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x03\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\"U\n\x1bSnortIdsIpAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x1b.SnortIdsIpAlertCountersDTO\"Q\n\x19SnortIdsAlertCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x19.SnortIdsAlertCountersDTO\"O\n\x18SnortIdsRuleCountersDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x18.SnortIdsRuleCountersDTO\"\xc9\x01\n\x1aSnortIdsIpAlertCountersDTO\x12\x17\n\x0fpriority_alerts\x18\x01 \x03(\x03\x12\x14\n\x0c\x63lass_alerts\x18\x02 \x03(\x03\x12\x15\n\rsevere_alerts\x18\x03 \x01(\x03\x12\x16\n\x0ewarning_alerts\x18\x04 \x01(\x03\x12#\n\x1b\x61lerts_weighted_by_priority\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\x12\x10\n\x08\x61lert_ip\x18\x08 \x01(\t\"^\n\x17SnortIdsRuleCountersDTO\x12\x10\n\x08rule_ids\x18\x01 \x03(\t\x12\x19\n\x11rule_alert_counts\x18\x02 \x03(\x03\x12\n\n\x02ip\x18\x03 \x01(\t\x12\n\n\x02ts\x18\x04 \x01(\x02\"\xf4\x01\n\x1a\x45mulationAttackerActionDTO\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x03\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x03\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\x12\x15\n\rvulnerability\x18\x0c \x01(\t\x12\x10\n\x08\x62\x61\x63kdoor\x18\r \x01(\x08\"\xcb\x01\n\x1a\x45mulationDefenderActionDTO\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63mds\x18\x03 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\x03\x12\r\n\x05\x64\x65scr\x18\x05 \x01(\t\x12\x0b\n\x03ips\x18\x06 \x03(\t\x12\r\n\x05index\x18\x07 \x01(\x03\x12\x16\n\x0e\x61\x63tion_outcome\x18\x08 \x01(\x03\x12\x10\n\x08\x61lt_cmds\x18\t \x03(\t\x12\x16\n\x0e\x65xecution_time\x18\n \x01(\x02\x12\n\n\x02ts\x18\x0b \x01(\x02\"\xce\x01\n\x12HostMetricsDataDTO\x12\x1b\n\x13num_logged_in_users\x18\x01 \x01(\x03\x12!\n\x19num_failed_login_attempts\x18\x02 \x01(\x03\x12\x1c\n\x14num_open_connections\x18\x03 \x01(\x03\x12\x18\n\x10num_login_events\x18\x04 \x01(\x03\x12\x15\n\rnum_processes\x18\x05 \x01(\x03\x12\x11\n\tnum_users\x18\x06 \x01(\x03\x12\n\n\x02ip\x18\x07 \x01(\t\x12\n\n\x02ts\x18\x08 \x01(\x02\"\xf8\x01\n\x0e\x44ockerStatsDTO\x12\x0c\n\x04pids\x18\x01 \x01(\x02\x12\x11\n\ttimestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x63pu_percent\x18\x03 \x01(\x02\x12\x13\n\x0bmem_current\x18\x04 \x01(\x02\x12\x11\n\tmem_total\x18\x05 \x01(\x02\x12\x13\n\x0bmem_percent\x18\x06 \x01(\x02\x12\x10\n\x08\x62lk_read\x18\x07 \x01(\x02\x12\x11\n\tblk_write\x18\x08 \x01(\x02\x12\x0e\n\x06net_rx\x18\t \x01(\x02\x12\x0e\n\x06net_tx\x18\n \x01(\x02\x12\x16\n\x0e\x63ontainer_name\x18\x0b \x01(\t\x12\n\n\x02ip\x18\x0c \x01(\t\x12\n\n\x02ts\x18\r \x01(\x02\"m\n\x1a\x43lientPopulationMetricsDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x02\x12\x13\n\x0bnum_clients\x18\x03 \x01(\x03\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x14\n\x0cservice_time\x18\x05 \x01(\x02\"\x1a\n\x18GetClusterManagerLogsMsg\"S\n\x13GetContainerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17GetClientManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16GetKafkaManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\":\n\x0fGetKafkaLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"R\n\x12GetSnortIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetSnortIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Y\n\x19GetOSSECIdsManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12GetOSSECIdsLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15GetHostManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18GetTrafficManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14GetElkManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"8\n\rGetElkLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14GetRyuManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17GetRyuControllerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17StopRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18StartRyuMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"D\n\x19StopHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"X\n\x18StopHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"@\n\x15RemoveKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15\x43reateKibanaTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\x16\n\x14ListKibanaTunnelsMsg\"5\n\x10KibanaTunnelsDTO\x12!\n\x07tunnels\x18\x01 \x03(\x0b\x32\x10.KibanaTunnelDTO\"T\n\x0fKibanaTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x03\"@\n\x15Remove5GCoreTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15\x43reate5GCoreTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\x16\n\x14List5GCoreTunnelsMsg\";\n\x13\x46iveGCoreTunnelsDTO\x12$\n\x07tunnels\x18\x01 \x03(\x0b\x32\x13.FiveGCoreTunnelDTO\"W\n\x12\x46iveGCoreTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x03\"=\n\x12RemoveRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12\x43reateRyuTunnelMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\x13\n\x11ListRyuTunnelsMsg\"/\n\rRyuTunnelsDTO\x12\x1e\n\x07tunnels\x18\x01 \x03(\x0b\x32\r.RyuTunnelDTO\"Q\n\x0cRyuTunnelDTO\x12\x0c\n\x04port\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\temulation\x18\x03 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x04 \x01(\x03\"P\n SnortIdsMonitorThreadStatusesDTO\x12,\n\x10snortIDSStatuses\x18\x01 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"E\n\x1aGetSnortIdsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"N\n#GetSnortIdsMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"H\n\x1dStopSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"V\n\x16StopSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StartSnortIdsManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"B\n\x17StopSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18StartSnortIdsManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"M\n\rStartSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"I\n\x1eStartSnortIdsMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"L\n\x0cStopSnortMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\\\n\x1cStopSnortIdsMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"J\n\x1fStopSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15GetRyuManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18StopRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"D\n\x19StartRyuMonitorServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11StopRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StartRyuServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16GetRyuServiceStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11StopRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StartRyuManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"E\n\x1aGetOSSECIDSManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"P\n OSSECIdsMonitorThreadStatusesDTO\x12,\n\x10ossecIDSStatuses\x18\x01 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"N\n#GetOSSECIDSMonitorThreadStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"H\n\x1dStopOSSECIDSMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\\\n\x1cStopOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"]\n\x1dStartOSSECIDSMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StopOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"T\n\x14StartOSSECIDSManager\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"?\n\x14StopOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15StartOSSECIDSManagers\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"P\n\x10StartOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopOSSECIDSMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"=\n\x12StartOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11StopOSSECIDSesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17GetKafkaManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13StartKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StopKafkaServerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18GetKafkaManagerStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14\x43reateKafkaTopicsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13StopKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14StartKafkaManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16GetHostManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"K\n GetHostMonitorThreadsStatusesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"V\n\x16\x41pplyFileBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyPacketBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"X\n\x18\x41pplyMetricBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17\x41pplyHeartBeatConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"O\n\x0fStopFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"Q\n\x11StopMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"P\n\x10StopHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"f\n\x10StartFileBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartPacketBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"h\n\x12StartMetricBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"g\n\x11StartHeartBeatMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\x12\x13\n\x0b\x63ontainerIp\x18\x04 \x01(\t\"Y\n\x19StartHostMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"<\n\x11StopHeartbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StopPacketbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\";\n\x10StopFilebeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StopMetricbeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"E\n\x1aStartHostMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"R\n\x12StopHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"S\n\x13StartHostManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\">\n\x13StopHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xdc\x06\n\x10\x45xecutionInfoDTO\x12\x15\n\remulationName\x18\x01 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x02 \x01(\x03\x12\x36\n\x14snortIdsManagersInfo\x18\x03 \x01(\x0b\x32\x18.SnortIdsManagersInfoDTO\x12\x36\n\x14ossecIdsManagersInfo\x18\x04 \x01(\x0b\x32\x18.OSSECIdsManagersInfoDTO\x12\x30\n\x11kafkaManagersInfo\x18\x05 \x01(\x0b\x32\x15.KafkaManagersInfoDTO\x12.\n\x10hostManagersInfo\x18\x06 \x01(\x0b\x32\x14.HostManagersInfoDTO\x12\x32\n\x12\x63lientManagersInfo\x18\x07 \x01(\x0b\x32\x16.ClientManagersInfoDTO\x12<\n\x17\x64ockerStatsManagersInfo\x18\x08 \x01(\x0b\x32\x1b.DockerStatsManagersInfoDTO\x12\x30\n\x11runningContainers\x18\t \x01(\x0b\x32\x15.RunningContainersDTO\x12\x30\n\x11stoppedContainers\x18\n \x01(\x0b\x32\x15.StoppedContainersDTO\x12\x37\n\x16trafficManagersInfoDTO\x18\x0b \x01(\x0b\x32\x17.TrafficManagersInfoDTO\x12*\n\x0e\x61\x63tiveNetworks\x18\x0c \x01(\x0b\x32\x12.DockerNetworksDTO\x12/\n\x12\x65lkManagersInfoDTO\x18\r \x01(\x0b\x32\x13.ElkManagersInfoDTO\x12/\n\x12ryuManagersInfoDTO\x18\x0e \x01(\x0b\x32\x13.RyuManagersInfoDTO\x12;\n\x18\x66iveGCoreManagersInfoDTO\x18\x0f \x01(\x0b\x32\x19.FiveGCoreManagersInfoDTO\x12\x37\n\x16\x66iveGCUManagersInfoDTO\x18\x10 \x01(\x0b\x32\x17.FiveGCUManagersInfoDTO\x12\x37\n\x16\x66iveGDUManagersInfoDTO\x18\x11 \x01(\x0b\x32\x17.FiveGDUManagersInfoDTO\"\xe5\x01\n\x12RyuManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1a\n\x12ryuManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x13ryuManagersStatuses\x18\x06 \x03(\x0b\x32\x14.RyuManagerStatusDTO\x12\x1e\n\x16localControllerWebPort\x18\x07 \x01(\x03\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"\xb4\x01\n\x13RyuManagerStatusDTO\x12\x13\n\x0bryu_running\x18\x01 \x01(\x08\x12\x17\n\x0fmonitor_running\x18\x02 \x01(\x08\x12\x0c\n\x04port\x18\x03 \x01(\x03\x12\x10\n\x08web_port\x18\x04 \x01(\x03\x12\x12\n\ncontroller\x18\x05 \x01(\t\x12\x10\n\x08kafka_ip\x18\x06 \x01(\t\x12\x12\n\nkafka_port\x18\x07 \x01(\x03\x12\x15\n\rtime_step_len\x18\x08 \x01(\x03\"\xaf\x01\n\x13HostManagersInfoDTO\x12\x0b\n\x03ips\x18\x15 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1b\n\x13hostManagersRunning\x18\x05 \x03(\x08\x12\x33\n\x14hostManagersStatuses\x18\x06 \x03(\x0b\x32\x15.HostManagerStatusDTO\"L\n\x16HostManagerStatusesDTO\x12\x32\n\x13hostManagerStatuses\x18\x01 \x03(\x0b\x32\x15.HostManagerStatusDTO\"\xa8\x01\n\x14HostManagerStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x18\n\x10\x66ilebeat_running\x18\x02 \x01(\x08\x12\x1a\n\x12packetbeat_running\x18\x03 \x01(\x08\x12\x1a\n\x12metricbeat_running\x18\x04 \x01(\x08\x12\x19\n\x11heartbeat_running\x18\x05 \x01(\x08\x12\n\n\x02ip\x18\x06 \x01(\t\"\xac\x01\n\x14KafkaManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1c\n\x14kafkaManagersRunning\x18\x05 \x03(\x08\x12.\n\x15kafkaManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.KafkaStatusDTO\"1\n\x0eKafkaStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06topics\x18\x02 \x03(\t\"\xb8\x01\n\x17OSSECIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1f\n\x17ossecIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18ossecIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.OSSECIdsStatusDTO\"G\n\x11OSSECIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11ossec_ids_running\x18\x02 \x01(\x08\"\xb8\x01\n\x17SnortIdsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1f\n\x17snortIdsManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x18snortIdsManagersStatuses\x18\x06 \x03(\x0b\x32\x12.SnortIdsStatusDTO\"G\n\x11SnortIdsStatusDTO\x12\x17\n\x0fmonitor_running\x18\x01 \x01(\x08\x12\x19\n\x11snort_ids_running\x18\x02 \x01(\x08\">\n\x13GetExecutionInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"G\n\x1cStopContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"y\n\x0fRunContainerMsg\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06memory\x18\x03 \x01(\x03\x12\x10\n\x08num_cpus\x18\x04 \x01(\x03\x12\x16\n\x0e\x63reate_network\x18\x05 \x01(\x08\x12\x0f\n\x07version\x18\x06 \x01(\t\"H\n\x1dStartContainersOfExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15GetElkManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xd7\x01\n\x12\x45lkManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1a\n\x12\x65lkManagersRunning\x18\x05 \x03(\x08\x12*\n\x13\x65lkManagersStatuses\x18\x06 \x03(\x0b\x32\r.ElkStatusDTO\x12\x17\n\x0flocalKibanaPort\x18\x07 \x01(\x03\x12\x18\n\x10physicalServerIp\x18\x08 \x01(\t\"A\n\x16StopLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17StartLogstashServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14StopKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15StartKibanaServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15StopElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16StartElasticServiceMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\":\n\x0fStopElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"V\n\x0c\x45lkStatusDTO\x12\x16\n\x0e\x65lasticRunning\x18\x01 \x01(\x08\x12\x15\n\rkibanaRunning\x18\x02 \x01(\x08\x12\x17\n\x0flogstashRunning\x18\x03 \x01(\x08\"?\n\x14GetElkStackStatusMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11StopElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StartElkManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"H\n\x1dGetDockerStatsManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xcb\x01\n\x1a\x44ockerStatsManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\"\n\x1a\x64ockerStatsManagersRunning\x18\x05 \x03(\x08\x12\x41\n\x1b\x64ockerStatsManagersStatuses\x18\x06 \x03(\x0b\x32\x1c.DockerStatsMonitorStatusDTO\"\x1c\n\x1aRemoveAllDockerNetworksMsg\"+\n\x17RemoveDockerNetworksMsg\x12\x10\n\x08networks\x18\x01 \x03(\t\"e\n\x1b\x44ockerStatsMonitorStatusDTO\x12\x14\n\x0cnum_monitors\x18\x01 \x01(\x03\x12\x12\n\nemulations\x18\x02 \x03(\t\x12\x1c\n\x14\x65mulation_executions\x18\x03 \x03(\x03\".\n\x1eGetDockerStatsManagerStatusMsg\x12\x0c\n\x04port\x18\x01 \x01(\x03\"J\n\x1fStopDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"E\n\x1a\x43reateEmulationNetworksMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\x1d\n\x1bListAllStoppedContainersMsg\"F\n\x14StoppedContainersDTO\x12.\n\x11stoppedContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"\x1d\n\x1bListAllRunningEmulationsMsg\"1\n\x14RunningEmulationsDTO\x12\x19\n\x11runningEmulations\x18\x01 \x03(\t\"\x1d\n\x1bListAllRunningContainersMsg\"F\n\x14RunningContainersDTO\x12.\n\x11runningContainers\x18\x01 \x03(\x0b\x32\x13.DockerContainerDTO\"=\n\x12\x44ockerContainerDTO\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x01(\t\"!\n\x11StartContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x1cStartAllStoppedContainersMsg\"\x1a\n\x18ListAllDockerNetworksMsg\":\n\x11\x44ockerNetworksDTO\x12\x10\n\x08networks\x18\x01 \x03(\t\x12\x13\n\x0bnetwork_ids\x18\x02 \x03(\x03\"8\n\x12\x43ontainerImagesDTO\x12\"\n\x06images\x18\x01 \x03(\x0b\x32\x12.ContainerImageDTO\"f\n\x11\x43ontainerImageDTO\x12\x10\n\x08repoTags\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\n\n\x02os\x18\x03 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x04 \x01(\t\x12\x0c\n\x04size\x18\x05 \x01(\x03\"\x1b\n\x19ListAllContainerImagesMsg\"\'\n\x17RemoveContainerImageMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bRemoveAllContainerImagesMsg\"\x1f\n\x1dRemoveAllStoppedContainersMsg\"\"\n\x12RemoveContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10StopContainerMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\x1bStopAllRunningContainersMsg\"D\n\x19GetTrafficManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xb9\x01\n\x16TrafficManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1e\n\x16trafficManagersRunning\x18\x05 \x03(\x08\x12\x37\n\x17trafficManagersStatuses\x18\x06 \x03(\x0b\x32\x16.TrafficManagerInfoDTO\"8\n\x15TrafficManagerInfoDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\x12\x0e\n\x06script\x18\x02 \x01(\t\"\xb1\x01\n\x15\x43lientManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1d\n\x15\x63lientManagersRunning\x18\x05 \x03(\x08\x12\x31\n\x16\x63lientManagersStatuses\x18\x06 \x03(\x0b\x32\x11.GetNumClientsDTO\"C\n\x18GetClientManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"X\n\x18StartTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"W\n\x17StopTrafficGeneratorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"C\n\x18StopTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xae\x01\n\x10GetNumClientsDTO\x12\x13\n\x0bnum_clients\x18\x01 \x01(\x03\x12\x1d\n\x15\x63lient_process_active\x18\x02 \x01(\x08\x12\x17\n\x0fproducer_active\x18\x03 \x01(\x08\x12%\n\x1d\x63lients_time_step_len_seconds\x18\x04 \x01(\x03\x12&\n\x1eproducer_time_step_len_seconds\x18\x05 \x01(\x03\"A\n\x16GetNumActiveClientsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17StopClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14StopClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15StartClientManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16StopTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"U\n\x15StopTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"V\n\x16StartTrafficManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"\x17\n\x15\x43leanAllExecutionsMsg\"\x16\n\x14StopAllExecutionsMsg\";\n\x10StopExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11\x43leanExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"4\n\x1fStopAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"5\n CleanAllExecutionsOfEmulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\"\x14\n\x12GetCsleLogFilesMsg\"\x1d\n\rGetLogFileMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\"H\n\x1dStartContainersInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"S\n(AttachContainersToNetworksInExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13InstallLibrariesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13\x41pplyKafkaConfigMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15StartSdnControllerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"E\n\x1a\x41pplyResouceConstraintsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14\x43reateOvsSwitchesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\";\n\x10PingExecutionMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\":\n\x0f\x43onfigureOvsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"G\n\x1cStartSdnControllerMonitorMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"9\n\x0e\x43reateUsersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"9\n\x0e\x43reateVulnsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"9\n\x0e\x43reateFlagsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"<\n\x11\x43reateTopologyMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17StartTrafficManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"D\n\x19StartTrafficGeneratorsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18StartClientPopulationMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"F\n\x1bStartKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"E\n\x1aStopKafkaClientProducerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StartSnortIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"K\n StartSnortIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"=\n\x12StartOSSECIdsesMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"K\n StartOSSECIdsesMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\";\n\x10StartElkStackMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14StartHostManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"B\n\x17\x41pplyFileBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"D\n\x19\x41pplyPacketBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"D\n\x19\x41pplyMetricBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18\x41pplyHeartBeatConfigsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"R\n\x11StartFileBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartPacketBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"T\n\x13StartMetricBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"S\n\x12StartHeartBeatsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x14\n\x0cinitialStart\x18\x03 \x01(\x08\"\x1e\n\x1cGetDockerStatsManagerLogsMsg\"\x16\n\x14GetPrometheusLogsMsg\"\x18\n\x16GetNodeExporterLogsMsg\"\x14\n\x12GetCAdvisorLogsMsg\"\x13\n\x11GetPgAdminLogsMsg\"\x13\n\x11GetGrafanaLogsMsg\"\x11\n\x0fGetNginxLogsMsg\"\x12\n\x10GetDockerLogsMsg\"\x16\n\x14GetPostgreSQLLogsMsg\"\x11\n\x0fGetFlaskLogsMsg\"\x17\n\x07LogsDTO\x12\x0c\n\x04logs\x18\x01 \x03(\t\"&\n\x13OperationOutcomeDTO\x12\x0f\n\x07outcome\x18\x01 \x01(\x08\"\x12\n\x10GetNodeStatusMsg\"\xb3\x02\n\rNodeStatusDTO\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06leader\x18\x02 \x01(\x08\x12\x17\n\x0f\x63\x41\x64visorRunning\x18\x03 \x01(\x08\x12\x19\n\x11prometheusRunning\x18\x04 \x01(\x08\x12\x16\n\x0egrafanaRunning\x18\x05 \x01(\x08\x12\x16\n\x0epgAdminRunning\x18\x06 \x01(\x08\x12\x14\n\x0cnginxRunning\x18\x07 \x01(\x08\x12\x14\n\x0c\x66laskRunning\x18\x08 \x01(\x08\x12!\n\x19\x64ockerStatsManagerRunning\x18\t \x01(\x08\x12\x1b\n\x13nodeExporterRunning\x18\n \x01(\x08\x12\x19\n\x11postgreSQLRunning\x18\x0b \x01(\x08\x12\x1b\n\x13\x64ockerEngineRunning\x18\x0c \x01(\x08\"#\n\x10ServiceStatusDTO\x12\x0f\n\x07running\x18\x01 \x01(\x08\"\x14\n\x12StartPostgreSQLMsg\"\x12\n\x10StartCAdvisorMsg\"\x16\n\x14StartNodeExporterMsg\"\x11\n\x0fStartGrafanaMsg\"\x14\n\x12StartPrometheusMsg\"\x11\n\x0fStartPgAdminMsg\"\x0f\n\rStartNginxMsg\"\x0f\n\rStartFlaskMsg\"\x1c\n\x1aStartDockerStatsManagerMsg\"K\n StartDockerStatsManagerThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\x16\n\x14StartDockerEngineMsg\"\x13\n\x11StopPostgreSQLMsg\"\x11\n\x0fStopCAdvisorMsg\"\x15\n\x13StopNodeExporterMsg\"\x10\n\x0eStopGrafanaMsg\"\x13\n\x11StopPrometheusMsg\"\x10\n\x0eStopPgAdminMsg\"\x0e\n\x0cStopNginxMsg\"\x0e\n\x0cStopFlaskMsg\"\x1b\n\x19StopDockerStatsManagerMsg\"\x15\n\x13StopDockerEngineMsg\"A\n\x16Start5GCoreManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"@\n\x15Stop5GCoreManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"U\n\x15Start5GCoreManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"T\n\x14Stop5GCoreManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"M\n\rStop5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"9\n\x0eStop5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"N\n\x0eStart5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\":\n\x0fStart5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"M\n\rInit5GCoreMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"9\n\x0eInit5GCoresMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14Start5GCUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13Stop5GCUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"S\n\x13Start5GCUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12Stop5GCUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"K\n\x0bStop5GCUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GCUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"L\n\x0cStart5GCUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GCUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"K\n\x0bInit5GCUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cInit5GCUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"?\n\x14Start5GDUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\">\n\x13Stop5GDUManagersMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"S\n\x13Start5GDUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"R\n\x12Stop5GDUManagerMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"K\n\x0bStop5GDUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GDUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"L\n\x0cStart5GDUMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GDUsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"K\n\x0bStop5GUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"7\n\x0cStop5GUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"L\n\x0cStart5GUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"8\n\rStart5GUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"M\n\rInit5GDUUEMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"9\n\x0eInit5GDUUEsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"C\n\x18Get5GCoreManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16Get5GCUManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"A\n\x16Get5GDUManagersInfoMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"\xd0\x03\n\x10\x46iveGCoreInfoDTO\x12\x15\n\rmongo_running\x18\x01 \x01(\x08\x12\x13\n\x0bmme_running\x18\x02 \x01(\x08\x12\x14\n\x0csgwc_running\x18\x03 \x01(\x08\x12\x13\n\x0bsmf_running\x18\x04 \x01(\x08\x12\x13\n\x0b\x61mf_running\x18\x05 \x01(\x08\x12\x14\n\x0csgwu_running\x18\x06 \x01(\x08\x12\x13\n\x0bupf_running\x18\x07 \x01(\x08\x12\x13\n\x0bhss_running\x18\x08 \x01(\x08\x12\x14\n\x0cpcrf_running\x18\t \x01(\x08\x12\x13\n\x0bnrf_running\x18\n \x01(\x08\x12\x13\n\x0bscp_running\x18\x0b \x01(\x08\x12\x14\n\x0csepp_running\x18\x0c \x01(\x08\x12\x14\n\x0c\x61usf_running\x18\r \x01(\x08\x12\x13\n\x0budm_running\x18\x0e \x01(\x08\x12\x13\n\x0bpcf_running\x18\x0f \x01(\x08\x12\x14\n\x0cnssf_running\x18\x10 \x01(\x08\x12\x13\n\x0b\x62sf_running\x18\x11 \x01(\x08\x12\x13\n\x0budr_running\x18\x12 \x01(\x08\x12\x15\n\rwebui_running\x18\x13 \x01(\x08\x12\n\n\x02ip\x18\x14 \x01(\t\x12\x17\n\x0fmonitor_running\x18\x15 \x01(\x08\"I\n\x0e\x46iveGCUInfoDTO\x12\x12\n\ncu_running\x18\x01 \x01(\x08\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x17\n\x0fmonitor_running\x18\x03 \x01(\x08\"]\n\x0e\x46iveGDUInfoDTO\x12\x12\n\ndu_running\x18\x01 \x01(\x08\x12\x12\n\nue_running\x18\x02 \x01(\x08\x12\n\n\x02ip\x18\x03 \x01(\t\x12\x17\n\x0fmonitor_running\x18\x04 \x01(\x08\"\xba\x01\n\x18\x46iveGCoreManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12 \n\x18\x66iveGCoreManagersRunning\x18\x05 \x03(\x08\x12\x34\n\x19\x66iveGCoreManagersStatuses\x18\x06 \x03(\x0b\x32\x11.FiveGCoreInfoDTO\"\xb2\x01\n\x16\x46iveGCUManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1e\n\x16\x66iveGCUManagersRunning\x18\x05 \x03(\x08\x12\x30\n\x17\x66iveGCUManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.FiveGCUInfoDTO\"\xb2\x01\n\x16\x46iveGDUManagersInfoDTO\x12\x0b\n\x03ips\x18\x01 \x03(\t\x12\r\n\x05ports\x18\x02 \x03(\x03\x12\x15\n\remulationName\x18\x03 \x01(\t\x12\x13\n\x0b\x65xecutionId\x18\x04 \x01(\x03\x12\x1e\n\x16\x66iveGDUManagersRunning\x18\x05 \x03(\x08\x12\x30\n\x17\x66iveGDUManagersStatuses\x18\x06 \x03(\x0b\x32\x0f.FiveGDUInfoDTO\"W\n\x17Get5GCoreManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15Get5GCUManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"U\n\x15Get5GDUManagerLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"P\n\x10Get5GCoreLogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GCULogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GDULogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"N\n\x0eGet5GUELogsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"G\n\x1cStart5GCoreMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"[\n\x1bStart5GCoreMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"F\n\x1bStop5GCoreMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"Z\n\x1aStop5GCoreMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"E\n\x1aStart5GCUMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"Y\n\x19Start5GCUMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"D\n\x19Stop5GCUMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"X\n\x18Stop5GCUMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"E\n\x1aStart5GDUMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"Y\n\x19Start5GDUMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"D\n\x19Stop5GDUMonitorThreadsMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\"X\n\x18Stop5GDUMonitorThreadMsg\x12\x11\n\temulation\x18\x01 \x01(\t\x12\x14\n\x0cipFirstOctet\x18\x02 \x01(\x03\x12\x13\n\x0b\x63ontainerIp\x18\x03 \x01(\t\"M\n\x17\x46iveGCoreAMFMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCoreAMFMetricsDTO\"\xad\x07\n\x16\x46iveGCoreAMFMetricsDTO\x12\x0b\n\x03gnb\x18\x01 \x01(\x03\x12(\n fivegs_amffunction_mm_confupdate\x18\x02 \x01(\x03\x12(\n fivegs_amffunction_rm_reginitreq\x18\x03 \x01(\x03\x12)\n!fivegs_amffunction_rm_regemergreq\x18\x04 \x01(\x03\x12)\n!fivegs_amffunction_mm_paging5greq\x18\x05 \x01(\x03\x12*\n\"fivegs_amffunction_rm_regperiodreq\x18\x06 \x01(\x03\x12,\n$fivegs_amffunction_mm_confupdatesucc\x18\x07 \x01(\x03\x12)\n!fivegs_amffunction_rm_reginitsucc\x18\x08 \x01(\x03\x12)\n!fivegs_amffunction_amf_authreject\x18\t \x01(\x03\x12\'\n\x1f\x66ivegs_amffunction_rm_regmobreq\x18\n \x01(\x03\x12\x13\n\x0b\x61mf_session\x18\x0b \x01(\x03\x12(\n fivegs_amffunction_rm_regmobsucc\x18\x0c \x01(\x03\x12&\n\x1e\x66ivegs_amffunction_amf_authreq\x18\r \x01(\x03\x12*\n\"fivegs_amffunction_rm_regemergsucc\x18\x0e \x01(\x03\x12*\n\"fivegs_amffunction_mm_paging5gsucc\x18\x0f \x01(\x03\x12\x0e\n\x06ran_ue\x18\x10 \x01(\x03\x12+\n#fivegs_amffunction_rm_regperiodsucc\x18\x11 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x12 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\x13 \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\x14 \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\x15 \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\x16 \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\x17 \x01(\x03\x12\x18\n\x10process_open_fds\x18\x18 \x01(\x03\x12\n\n\x02ip\x18\x19 \x01(\t\x12\n\n\x02ts\x18\x1a \x01(\x02\"M\n\x17\x46iveGCoreHSSMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCoreHSSMetricsDTO\"\xe8\x08\n\x16\x46iveGCoreHSSMetricsDTO\x12\x11\n\tcx_rx_lir\x18\x01 \x01(\x03\x12\x11\n\tcx_rx_uar\x18\x02 \x01(\x03\x12\x11\n\tcx_tx_lia\x18\x03 \x01(\x03\x12\x15\n\rcx_rx_unknown\x18\x04 \x01(\x03\x12\x11\n\tcx_rx_sar\x18\x05 \x01(\x03\x12\x12\n\ns6a_rx_pur\x18\x06 \x01(\x03\x12\x18\n\x10swx_rx_mar_error\x18\x07 \x01(\x03\x12\x11\n\tcx_tx_uaa\x18\x08 \x01(\x03\x12\x18\n\x10s6a_rx_pur_error\x18\t \x01(\x03\x12\x12\n\ns6a_tx_clr\x18\n \x01(\x03\x12\x11\n\tcx_tx_saa\x18\x0b \x01(\x03\x12\x17\n\x0f\x63x_rx_lir_error\x18\x0c \x01(\x03\x12\x12\n\ns6a_rx_ulr\x18\r \x01(\x03\x12\x12\n\ns6a_rx_cla\x18\x0e \x01(\x03\x12\x18\n\x10s6a_rx_cla_error\x18\x0f \x01(\x03\x12\x12\n\ns6a_rx_air\x18\x10 \x01(\x03\x12\x11\n\tcx_rx_mar\x18\x11 \x01(\x03\x12\x12\n\nswx_rx_sar\x18\x12 \x01(\x03\x12\x18\n\x10s6a_rx_air_error\x18\x13 \x01(\x03\x12\x18\n\x10s6a_rx_ida_error\x18\x14 \x01(\x03\x12\x11\n\tcx_tx_maa\x18\x15 \x01(\x03\x12\x12\n\nswx_rx_mar\x18\x16 \x01(\x03\x12\x16\n\x0es6a_rx_unknown\x18\x17 \x01(\x03\x12\x12\n\ns6a_tx_pua\x18\x18 \x01(\x03\x12\x16\n\x0eswx_rx_unknown\x18\x19 \x01(\x03\x12\x17\n\x0f\x63x_rx_mar_error\x18\x1a \x01(\x03\x12\x17\n\x0f\x63x_rx_uar_error\x18\x1b \x01(\x03\x12\x12\n\ns6a_tx_ula\x18\x1c \x01(\x03\x12\x18\n\x10s6a_rx_ulr_error\x18\x1d \x01(\x03\x12\x12\n\ns6a_tx_aia\x18\x1e \x01(\x03\x12\x12\n\ns6a_tx_idr\x18\x1f \x01(\x03\x12\x12\n\ns6a_rx_ida\x18  \x01(\x03\x12\x17\n\x0f\x63x_rx_sar_error\x18! \x01(\x03\x12\x18\n\x10swx_rx_sar_error\x18\" \x01(\x03\x12\x12\n\nswx_tx_maa\x18# \x01(\x03\x12\x12\n\nswx_tx_saa\x18$ \x01(\x03\x12\x10\n\x08hss_imsi\x18% \x01(\x03\x12\x10\n\x08hss_impi\x18& \x01(\x03\x12\x10\n\x08hss_impu\x18\' \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18( \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18) \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18* \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18+ \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18, \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18- \x01(\x03\x12\x18\n\x10process_open_fds\x18. \x01(\x03\x12\n\n\x02ip\x18/ \x01(\t\x12\n\n\x02ts\x18\x30 \x01(\x02\"M\n\x17\x46iveGCoreMMEMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCoreMMEMetricsDTO\"\xd3\x02\n\x16\x46iveGCoreMMEMetricsDTO\x12\x0e\n\x06\x65nb_ue\x18\x01 \x01(\x03\x12\x13\n\x0bmme_session\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nb\x18\x03 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x04 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\x05 \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\x06 \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\x07 \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\x08 \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\t \x01(\x03\x12\x18\n\x10process_open_fds\x18\n \x01(\x03\x12\n\n\x02ip\x18\x0b \x01(\t\x12\n\n\x02ts\x18\x0c \x01(\x02\"M\n\x17\x46iveGCorePCFMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCorePCFMetricsDTO\"\x89\x04\n\x16\x46iveGCorePCFMetricsDTO\x12-\n%fivegs_pcffunction_pa_policyamassoreq\x18\x01 \x01(\x03\x12.\n&fivegs_pcffunction_pa_policyamassosucc\x18\x02 \x01(\x03\x12-\n%fivegs_pcffunction_pa_policysmassoreq\x18\x03 \x01(\x03\x12.\n&fivegs_pcffunction_pa_policysmassosucc\x18\x04 \x01(\x03\x12(\n fivegs_pcffunction_pa_sessionnbr\x18\x05 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x06 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\x07 \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\x08 \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\t \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\n \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\x0b \x01(\x03\x12\x18\n\x10process_open_fds\x18\x0c \x01(\x03\x12\n\n\x02ip\x18\r \x01(\t\x12\n\n\x02ts\x18\x0e \x01(\x02\"O\n\x18\x46iveGCorePCRFMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x18.FiveGCorePCRFMetricsDTO\"\xf8\x04\n\x17\x46iveGCorePCRFMetricsDTO\x12\x15\n\rgx_rx_unknown\x18\x01 \x01(\x03\x12\x11\n\tgx_rx_ccr\x18\x02 \x01(\x03\x12\x17\n\x0fgx_rx_ccr_error\x18\x03 \x01(\x03\x12\x11\n\tgx_rx_raa\x18\x04 \x01(\x03\x12\x11\n\tgx_tx_cca\x18\x05 \x01(\x03\x12\x11\n\tgx_tx_rar\x18\x06 \x01(\x03\x12\x17\n\x0fgx_tx_rar_error\x18\x07 \x01(\x03\x12\x15\n\rrx_rx_unknown\x18\x08 \x01(\x03\x12\x11\n\trx_rx_aar\x18\t \x01(\x03\x12\x17\n\x0frx_rx_aar_error\x18\n \x01(\x03\x12\x11\n\trx_rx_asa\x18\x0b \x01(\x03\x12\x17\n\x0frx_rx_asa_error\x18\x0c \x01(\x03\x12\x17\n\x0frx_rx_str_error\x18\r \x01(\x03\x12\x11\n\trx_tx_aaa\x18\x0e \x01(\x03\x12\x11\n\trx_tx_sar\x18\x0f \x01(\x03\x12\x11\n\trx_tx_sta\x18\x10 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x11 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\x12 \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\x13 \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\x14 \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\x15 \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\x16 \x01(\x03\x12\x18\n\x10process_open_fds\x18\x17 \x01(\x03\x12\n\n\x02ip\x18\x18 \x01(\t\x12\n\n\x02ts\x18\x19 \x01(\x02\"M\n\x17\x46iveGCoreSMFMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCoreSMFMetricsDTO\"\xef\x08\n\x16\x46iveGCoreSMFMetricsDTO\x12!\n\x19gn_rx_createpdpcontextreq\x18\x01 \x01(\x03\x12!\n\x19gn_rx_deletepdpcontextreq\x18\x02 \x01(\x03\x12\x1b\n\x13gtp1_pdpctxs_active\x18\x03 \x01(\x03\x12\x19\n\x11pfcp_peers_active\x18\x04 \x01(\x03\x12-\n%fivegs_smffunction_sm_n4sessionreport\x18\x05 \x01(\x03\x12\x12\n\nues_active\x18\x06 \x01(\x03\x12\x1c\n\x14gtp2_sessions_active\x18\x07 \x01(\x03\x12\x1c\n\x14pfcp_sessions_active\x18\x08 \x01(\x03\x12\x1c\n\x14s5c_rx_createsession\x18\t \x01(\x03\x12\x1c\n\x14s5c_rx_deletesession\x18\n \x01(\x03\x12\x1b\n\x13gtp_new_node_failed\x18\x0b \x01(\x03\x12\x1b\n\x13s5c_rx_parse_failed\x18\x0c \x01(\x03\x12\x31\n)fivegs_smffunction_sm_n4sessionreportsucc\x18\r \x01(\x03\x12/\n\'fivegs_smffunction_sm_n4sessionestabreq\x18\x0e \x01(\x03\x12\x16\n\x0e\x62\x65\x61rers_active\x18\x0f \x01(\x03\x12\x1a\n\x12gn_rx_parse_failed\x18\x10 \x01(\x03\x12\x18\n\x10gtp_peers_active\x18\x11 \x01(\x03\x12(\n fivegs_smffunction_sm_sessionnbr\x18\x12 \x01(\x03\x12\x33\n+fivegs_smffunction_sm_pdusessioncreationreq\x18\x13 \x01(\x03\x12\x34\n,fivegs_smffunction_sm_pdusessioncreationsucc\x18\x14 \x01(\x03\x12*\n\"fivegs_smffunction_sm_qos_flow_nbr\x18\x15 \x01(\x03\x12\x30\n(fivegs_smffunction_sm_n4sessionestabfail\x18\x16 \x01(\x03\x12\x34\n,fivegs_smffunction_sm_pdusessioncreationfail\x18\x17 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x18 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\x19 \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\x1a \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\x1b \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\x1c \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\x1d \x01(\x03\x12\x18\n\x10process_open_fds\x18\x1e \x01(\x03\x12\n\n\x02ip\x18\x1f \x01(\t\x12\n\n\x02ts\x18  \x01(\x02\"M\n\x17\x46iveGCoreUPFMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x17.FiveGCoreUPFMetricsDTO\"\xcd\x04\n\x16\x46iveGCoreUPFMetricsDTO\x12\'\n\x1f\x66ivegs_ep_n3_gtp_indatapktn3upf\x18\x01 \x01(\x03\x12(\n fivegs_ep_n3_gtp_outdatapktn3upf\x18\x02 \x01(\x03\x12/\n\'fivegs_upffunction_sm_n4sessionestabreq\x18\x03 \x01(\x03\x12-\n%fivegs_upffunction_sm_n4sessionreport\x18\x04 \x01(\x03\x12\x31\n)fivegs_upffunction_sm_n4sessionreportsucc\x18\x05 \x01(\x03\x12)\n!fivegs_upffunction_upf_sessionnbr\x18\x06 \x01(\x03\x12\x19\n\x11pfcp_peers_active\x18\x07 \x01(\x03\x12\x17\n\x0fprocess_max_fds\x18\x08 \x01(\x03\x12(\n process_virtual_memory_max_bytes\x18\t \x01(\x03\x12!\n\x19process_cpu_seconds_total\x18\n \x01(\x03\x12$\n\x1cprocess_virtual_memory_bytes\x18\x0b \x01(\x03\x12%\n\x1dprocess_resident_memory_bytes\x18\x0c \x01(\x03\x12\"\n\x1aprocess_start_time_seconds\x18\r \x01(\x03\x12\x18\n\x10process_open_fds\x18\x0e \x01(\x03\x12\n\n\x02ip\x18\x0f \x01(\t\x12\n\n\x02ts\x18\x10 \x01(\x02\"c\n\"FiveGCUAppResourceUsageMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x04\x64tos\x18\x02 \x03(\x0b\x32\".FiveGCUAppResourceUsageMetricsDTO\"\x90\x01\n!FiveGCUAppResourceUsageMetricsDTO\x12\x19\n\x11\x63pu_usage_percent\x18\x01 \x01(\x02\x12\x17\n\x0fmemory_usage_mb\x18\x02 \x01(\x02\x12\x1f\n\x17power_consumption_watts\x18\x03 \x01(\x02\x12\n\n\x02ip\x18\x04 \x01(\t\x12\n\n\x02ts\x18\x05 \x01(\x02\"W\n\x1c\x46iveGCUBufferPoolMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x1c.FiveGCUBufferPoolMetricsDTO\"Q\n\x1b\x46iveGCUBufferPoolMetricsDTO\x12\x1a\n\x12\x63\x65ntral_cache_size\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\x02\"G\n\x14\x46iveGCUCPMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x14.FiveGCUCPMetricsDTO\"\xe1\x06\n\x13\x46iveGCUCPMetricsDTO\x12\x10\n\x08\x63u_cp_id\x18\x01 \x01(\t\x12\x15\n\ramf_connected\x18\x02 \x01(\x08\x12(\n nof_cn_initiated_paging_requests\x18\x03 \x01(\x03\x12+\n#nof_pdu_sessions_requested_to_setup\x18\x04 \x01(\x03\x12+\n#nof_pdu_sessions_successfully_setup\x18\x05 \x01(\x03\x12.\n&nof_pdu_sessions_failed_to_setup_total\x18\x06 \x01(\x03\x12+\n#nof_handover_preparations_requested\x18\x07 \x01(\x03\x12,\n$nof_successful_handover_preparations\x18\x08 \x01(\x03\x12*\n\"rrc_establishments_attempted_total\x18\t \x01(\x03\x12+\n#rrc_establishments_successful_total\x18\n \x01(\x03\x12,\n$rrc_establishments_attempted_mo_data\x18\x0b \x01(\x03\x12-\n%rrc_establishments_successful_mo_data\x18\x0c \x01(\x03\x12+\n#rrc_establishments_attempted_mo_sig\x18\r \x01(\x03\x12,\n$rrc_establishments_successful_mo_sig\x18\x0e \x01(\x03\x12\x1f\n\x17max_nof_rrc_connections\x18\x0f \x01(\x03\x12 \n\x18mean_nof_rrc_connections\x18\x10 \x01(\x03\x12&\n\x1errc_reestablishments_attempted\x18\x11 \x01(\x03\x12\'\n\x1frrc_reestablishments_successful\x18\x12 \x01(\x03\x12)\n!nof_handover_executions_requested\x18\x13 \x01(\x03\x12*\n\"nof_successful_handover_executions\x18\x14 \x01(\x03\x12\n\n\x02ip\x18\x15 \x01(\t\x12\n\n\x02ts\x18\x16 \x01(\x02\"c\n\"FiveGDUAppResourceUsageMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x04\x64tos\x18\x02 \x03(\x0b\x32\".FiveGDUAppResourceUsageMetricsDTO\"\x90\x01\n!FiveGDUAppResourceUsageMetricsDTO\x12\x19\n\x11\x63pu_usage_percent\x18\x01 \x01(\x02\x12\x17\n\x0fmemory_usage_mb\x18\x02 \x01(\x02\x12\x1f\n\x17power_consumption_watts\x18\x03 \x01(\x02\x12\n\n\x02ip\x18\x04 \x01(\t\x12\n\n\x02ts\x18\x05 \x01(\x02\"W\n\x1c\x46iveGDUBufferPoolMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x1c.FiveGDUBufferPoolMetricsDTO\"Q\n\x1b\x46iveGDUBufferPoolMetricsDTO\x12\x1a\n\x12\x63\x65ntral_cache_size\x18\x01 \x01(\x03\x12\n\n\x02ip\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\x02\"K\n\x16\x46iveGDUCellMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x16.FiveGDUCellMetricsDTO\"\xbd\x02\n\x15\x46iveGDUCellMetricsDTO\x12\x0b\n\x03pci\x18\x01 \x01(\x03\x12\x17\n\x0f\x61verage_latency\x18\x02 \x01(\x02\x12\x13\n\x0bmax_latency\x18\x03 \x01(\x02\x12\x1e\n\x16pucch_tot_rb_usage_avg\x18\x04 \x01(\x02\x12\x12\n\nactive_ues\x18\x05 \x01(\x03\x12\x10\n\x08\x64l_brate\x18\x06 \x01(\x02\x12\x10\n\x08ul_brate\x18\x07 \x01(\x02\x12\x0e\n\x06\x64l_mcs\x18\x08 \x01(\x02\x12\x0e\n\x06ul_mcs\x18\t \x01(\x02\x12\x14\n\x0cpusch_snr_db\x18\n \x01(\x02\x12\x14\n\x0cpucch_snr_db\x18\x0b \x01(\x02\x12\x0b\n\x03\x63qi\x18\x0c \x01(\x02\x12\x0f\n\x07\x64l_bler\x18\r \x01(\x02\x12\x0f\n\x07ul_bler\x18\x0e \x01(\x02\x12\n\n\x02ip\x18\x0f \x01(\t\x12\n\n\x02ts\x18\x10 \x01(\x02\"I\n\x15\x46iveGDULowMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x15.FiveGDULowMetricsDTO\"\xdc\x02\n\x14\x46iveGDULowMetricsDTO\x12\x19\n\x11\x64l_avg_latency_us\x18\x01 \x01(\x02\x12\x1c\n\x14\x64l_cpu_usage_percent\x18\x02 \x01(\x02\x12\x19\n\x11\x64l_max_latency_us\x18\x03 \x01(\x02\x12\x18\n\x10\x64l_fec_tput_mbps\x18\x04 \x01(\x02\x12\x19\n\x11ul_avg_latency_us\x18\x05 \x01(\x02\x12\x1c\n\x14ul_cpu_usage_percent\x18\x06 \x01(\x02\x12\x19\n\x11ul_max_latency_us\x18\x07 \x01(\x02\x12\x12\n\nul_sinr_db\x18\x08 \x01(\x02\x12\x1c\n\x14ul_ch_est_latency_us\x18\t \x01(\x02\x12\x1e\n\x16ul_ldpc_dec_latency_us\x18\n \x01(\x02\x12\x18\n\x10ul_fec_tput_mbps\x18\x0b \x01(\x02\x12\n\n\x02ip\x18\x0c \x01(\t\x12\n\n\x02ts\x18\r \x01(\x02\"C\n\x12\x46iveGDUMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x04\x64tos\x18\x02 \x03(\x0b\x32\x12.FiveGDUMetricsDTO\"\x9f\x01\n\x11\x46iveGDUMetricsDTO\x12\x0b\n\x03pci\x18\x01 \x01(\x03\x12\x1a\n\x12\x61verage_latency_us\x18\x02 \x01(\x02\x12\x19\n\x11\x63pu_usage_percent\x18\x03 \x01(\x02\x12\x16\n\x0emax_latency_us\x18\x04 \x01(\x02\x12\x16\n\x0emin_latency_us\x18\x05 \x01(\x02\x12\n\n\x02ip\x18\x06 \x01(\t\x12\n\n\x02ts\x18\x07 \x01(\x02\"I\n\x15\x46iveGDURLCMetricsDict\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x04\x64tos\x18\x02 \x03(\x0b\x32\x15.FiveGDURLCMetricsDTO\"\xf5\x02\n\x14\x46iveGDURLCMetricsDTO\x12\r\n\x05ue_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x64rb_id\x18\x02 \x01(\x03\x12\x13\n\x0brx_num_pdus\x18\x03 \x01(\x03\x12\x14\n\x0crx_num_bytes\x18\x04 \x01(\x03\x12\x18\n\x10rx_num_lost_pdus\x18\x05 \x01(\x03\x12\x1d\n\x15rx_num_malformed_pdus\x18\x06 \x01(\x03\x12\x13\n\x0btx_num_sdus\x18\x07 \x01(\x03\x12\x14\n\x0ctx_num_bytes\x18\x08 \x01(\x03\x12\x1b\n\x13tx_num_dropped_sdus\x18\t \x01(\x03\x12\x1d\n\x15tx_num_discarded_sdus\x18\n \x01(\x03\x12\x1d\n\x15tx_max_pdu_latency_ns\x18\x0b \x01(\x03\x12\x1d\n\x15tx_sum_pdu_latency_ns\x18\x0c \x01(\x03\x12\x1d\n\x15tx_sum_sdu_latency_us\x18\r \x01(\x03\x12\n\n\x02ip\x18\x0e \x01(\t\x12\n\n\x02ts\x18\x0f \x01(\x02\x32\xcd\x8f\x01\n\x0e\x43lusterManager\x12\x34\n\rgetNodeStatus\x12\x11.GetNodeStatusMsg\x1a\x0e.NodeStatusDTO\"\x00\x12;\n\x0fstartPostgreSQL\x12\x13.StartPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x37\n\rstartCAdvisor\x12\x11.StartCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startNodeExporter\x12\x15.StartNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartGrafana\x12\x10.StartGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12;\n\x0fstartPrometheus\x12\x13.StartPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstartPgAdmin\x12\x10.StartPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartNginx\x12\x0e.StartNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x31\n\nstartFlask\x12\x0e.StartFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12K\n\x17startDockerStatsManager\x12\x1b.StartDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12W\n\x1dstartDockerStatsManagerThread\x12!.StartDockerStatsManagerThreadMsg\x1a\x11.ServiceStatusDTO\"\x00\x12?\n\x11startDockerEngine\x12\x15.StartDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPostgreSQL\x12\x12.StopPostgreSQLMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x35\n\x0cstopCAdvisor\x12\x10.StopCAdvisorMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopNodeExporter\x12\x14.StopNodeExporterMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopGrafana\x12\x0f.StopGrafanaMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x39\n\x0estopPrometheus\x12\x12.StopPrometheusMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x33\n\x0bstopPgAdmin\x12\x0f.StopPgAdminMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopNginx\x12\r.StopNginxMsg\x1a\x11.ServiceStatusDTO\"\x00\x12/\n\tstopFlask\x12\r.StopFlaskMsg\x1a\x11.ServiceStatusDTO\"\x00\x12I\n\x16stopDockerStatsManager\x12\x1a.StopDockerStatsManagerMsg\x1a\x11.ServiceStatusDTO\"\x00\x12=\n\x10stopDockerEngine\x12\x14.StopDockerEngineMsg\x1a\x11.ServiceStatusDTO\"\x00\x12\x32\n\x0fgetCsleLogFiles\x12\x13.GetCsleLogFilesMsg\x1a\x08.LogsDTO\"\x00\x12\x46\n\x19getDockerStatsManagerLogs\x12\x1d.GetDockerStatsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getPrometheusLogs\x12\x15.GetPrometheusLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getNodeExporterLogs\x12\x17.GetNodeExporterLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetCadvisorLogs\x12\x13.GetCAdvisorLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetPgAdminLogs\x12\x12.GetPgAdminLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x30\n\x0egetGrafanaLogs\x12\x12.GetGrafanaLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetNginxLogs\x12\x10.GetNginxLogsMsg\x1a\x08.LogsDTO\"\x00\x12.\n\rgetDockerLogs\x12\x11.GetDockerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x37\n\x12getPostrgreSQLLogs\x12\x15.GetPostgreSQLLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetFlaskLogs\x12\x10.GetFlaskLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetLogFile\x12\x0e.GetLogFileMsg\x1a\x08.LogsDTO\"\x00\x12T\n\x1astartContainersInExecution\x12\x1e.StartContainersInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12j\n%attachContainersInExecutionToNetworks\x12).AttachContainersToNetworksInExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10installLibraries\x12\x14.InstallLibrariesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10\x61pplyKafkaConfig\x12\x14.ApplyKafkaConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startSdnController\x12\x16.StartSdnControllerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12O\n\x18\x61pplyResourceConstraints\x12\x1b.ApplyResouceConstraintsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateOvsSwitches\x12\x15.CreateOvsSwitchesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rpingExecution\x12\x11.PingExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0c\x63onfigureOvs\x12\x10.ConfigureOvsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19startSdnControllerMonitor\x12\x1d.StartSdnControllerMonitorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateUsers\x12\x0f.CreateUsersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x15\x63reateVulnerabilities\x12\x0f.CreateVulnsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0b\x63reateFlags\x12\x0f.CreateFlagsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63reateTopology\x12\x12.CreateTopologyMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startTrafficGenerators\x12\x1a.StartTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startClientPopulation\x12\x19.StartClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18startKafkaClientProducer\x12\x1c.StartKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17stopKafkaClientProducer\x12\x1b.StopKafkaClientProducerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartSnortIdses\x12\x13.StartSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartSnortIdsesMonitorThreads\x12!.StartSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOssecIdses\x12\x13.StartOSSECIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1dstartOssecIdsesMonitorThreads\x12!.StartOSSECIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartElkStack\x12\x11.StartElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startHostManagers\x12\x15.StartHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyFileBeatsConfig\x12\x18.ApplyFileBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyPacketBeatsConfig\x12\x1a.ApplyPacketBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16\x61pplyMetricBeatsConfig\x12\x1a.ApplyMetricBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyHeartBeatsConfig\x12\x19.ApplyHeartBeatConfigsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartFilebeats\x12\x12.StartFileBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startPacketbeats\x12\x14.StartPacketBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startMetricbeats\x12\x14.StartMetricBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartHeartbeats\x12\x13.StartHeartBeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopAllExecutionsOfEmulation\x12 .StopAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopExecution\x12\x11.StopExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopAllExecutions\x12\x15.StopAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12\x63leanAllExecutions\x12\x16.CleanAllExecutionsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Z\n\x1d\x63leanAllExecutionsOfEmulation\x12!.CleanAllExecutionsOfEmulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0e\x63leanExecution\x12\x12.CleanExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13startTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x12stopTrafficManager\x12\x17.StartTrafficManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x13stopTrafficManagers\x12\x18.StartTrafficManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12startClientManager\x12\x16.StartClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopClientPopulation\x12\x18.StopClientPopulationMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stopClientManager\x12\x15.StopClientManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13getNumActiveClients\x12\x17.GetNumActiveClientsMsg\x1a\x11.GetNumClientsDTO\"\x00\x12J\n\x15startTrafficGenerator\x12\x19.StartTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopTrafficGenerators\x12\x19.StopTrafficGeneratorsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopTrafficGenerator\x12\x18.StopTrafficGeneratorMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x15getClientManagersInfo\x12\x19.GetClientManagersInfoMsg\x1a\x16.ClientManagersInfoDTO\"\x00\x12O\n\x16getTrafficManagersInfo\x12\x1a.GetTrafficManagersInfoMsg\x1a\x17.TrafficManagersInfoDTO\"\x00\x12P\n\x18stopAllRunningContainers\x12\x1c.StopAllRunningContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopContainer\x12\x11.StopContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1aremoveAllStoppedContainers\x12\x1e.RemoveAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveContainer\x12\x13.RemoveContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18removeAllContainerImages\x12\x1c.RemoveAllContainerImagesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14removeContainerImage\x12\x18.RemoveContainerImageMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12K\n\x16listAllContainerImages\x12\x1a.ListAllContainerImagesMsg\x1a\x13.ContainerImagesDTO\"\x00\x12H\n\x15listAllDockerNetworks\x12\x19.ListAllDockerNetworksMsg\x1a\x12.DockerNetworksDTO\"\x00\x12R\n\x19startAllStoppedContainers\x12\x1d.StartAllStoppedContainersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartContainer\x12\x12.StartContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12Q\n\x18listAllRunningContainers\x12\x1c.ListAllRunningContainersMsg\x1a\x15.RunningContainersDTO\"\x00\x12Q\n\x18listAllRunningEmulations\x12\x1c.ListAllRunningEmulationsMsg\x1a\x15.RunningEmulationsDTO\"\x00\x12Q\n\x18listAllStoppedContainers\x12\x1c.ListAllStoppedContainersMsg\x1a\x15.StoppedContainersDTO\"\x00\x12N\n\x17\x63reateEmulationNetworks\x12\x1b.CreateEmulationNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopDockerStatsManagerThread\x12 .StopDockerStatsManagerThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12^\n\x1bgetDockerStatsManagerStatus\x12\x1f.GetDockerStatsManagerStatusMsg\x1a\x1c.DockerStatsMonitorStatusDTO\"\x00\x12H\n\x14removeDockerNetworks\x12\x18.RemoveDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17removeAllDockerNetworks\x12\x1b.RemoveAllDockerNetworksMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12[\n\x1agetDockerStatsManagersInfo\x12\x1e.GetDockerStatsManagersInfoMsg\x1a\x1b.DockerStatsManagersInfoDTO\"\x00\x12>\n\x0fstartElkManager\x12\x13.StartElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopElkManager\x12\x12.StopElkManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0cgetElkStatus\x12\x15.GetElkStackStatusMsg\x1a\r.ElkStatusDTO\"\x00\x12\x38\n\x0cstopElkStack\x12\x10.StopElkStackMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstartElastic\x12\x17.StartElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstopElastic\x12\x16.StopElasticServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12=\n\x0bstartKibana\x12\x16.StartKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12;\n\nstopKibana\x12\x15.StopKibanaServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x41\n\rstartLogstash\x12\x18.StartLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cstopLogstash\x12\x17.StopLogstashServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getElkManagersInfo\x12\x16.GetElkManagersInfoMsg\x1a\x13.ElkManagersInfoDTO\"\x00\x12T\n\x1astartContainersOfExecution\x12\x1e.StartContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0crunContainer\x12\x10.RunContainerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopContainersOfExecution\x12\x1d.StopContainersOfExecutionMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startHostManager\x12\x14.StartHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopHostManagers\x12\x14.StopHostManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopHostManager\x12\x13.StopHostManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopFilebeats\x12\x11.StopFilebeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopPacketbeats\x12\x13.StopPacketbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopMetricbeats\x12\x13.StopMetricbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopHeartbeats\x12\x12.StopHeartbeatsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17startHostMonitorThreads\x12\x1b.StartHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16startHostMonitorThread\x12\x1a.StartHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartFilebeat\x12\x11.StartFileBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartPacketbeat\x12\x13.StartPacketBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartMetricbeat\x12\x13.StartMetricBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estartHeartbeat\x12\x12.StartHeartBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopFilebeat\x12\x10.StopFileBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopPacketbeat\x12\x12.StopPacketBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopMetricbeat\x12\x12.StopMetricBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstopHeartbeat\x12\x11.StopHeartBeatMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13\x61pplyFileBeatConfig\x12\x17.ApplyFileBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyPacketBeatConfig\x12\x19.ApplyPacketBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15\x61pplyMetricBeatConfig\x12\x19.ApplyMetricBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14\x61pplyHeartBeatConfig\x12\x18.ApplyHeartBeatConfigMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12]\n\x1dgetHostMonitorThreadsStatuses\x12!.GetHostMonitorThreadsStatusesMsg\x1a\x17.HostManagerStatusesDTO\"\x00\x12\x46\n\x13getHostManagersInfo\x12\x17.GetHostManagersInfoMsg\x1a\x14.HostManagersInfoDTO\"\x00\x12@\n\x10stopKafkaManager\x12\x14.StopKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11startKafkaManager\x12\x15.StartKafkaManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11\x63reateKafkaTopics\x12\x15.CreateKafkaTopicsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0egetKafkaStatus\x12\x19.GetKafkaManagerStatusMsg\x1a\x0f.KafkaStatusDTO\"\x00\x12>\n\x0fstopKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x10startKafkaServer\x12\x13.StopKafkaServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12I\n\x14getKafkaManagersInfo\x12\x18.GetKafkaManagersInfoMsg\x1a\x15.KafkaManagersInfoDTO\"\x00\x12<\n\x0estopOSSECIDSes\x12\x12.StopOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstartOSSECIDSes\x12\x13.StartOSSECIDSesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstopOSSECIDS\x12\x10.StopOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12:\n\rstartOSSECIDS\x12\x11.StartOSSECIDSMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12G\n\x15startOSSECIDSManagers\x12\x16.StartOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14stopOSSECIDSManagers\x12\x15.StopOSSECIDSManagers\x1a\x14.OperationOutcomeDTO\"\x00\x12\x45\n\x14startOSSECIDSManager\x12\x15.StartOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x13stopOSSECIDSManager\x12\x14.StopOSSECIDSManager\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartOSSECIDSMonitorThread\x12\x1e.StartOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopOSSECIDSMonitorThread\x12\x1d.StopOSSECIDSMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopOSSECIDSMonitorThreads\x12\x1e.StopOSSECIDSMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getOSSECIDSMonitorThreadStatuses\x12$.GetOSSECIDSMonitorThreadStatusesMsg\x1a!.OSSECIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getOSSECIdsManagersInfo\x12\x1b.GetOSSECIDSManagersInfoMsg\x1a\x18.OSSECIdsManagersInfoDTO\"\x00\x12>\n\x0fstartRyuManager\x12\x13.StartRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x0estopRyuManager\x12\x12.StopRyuManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12?\n\x0cgetRyuStatus\x12\x17.GetRyuServiceStatusMsg\x1a\x14.RyuManagerStatusDTO\"\x00\x12\x37\n\x08startRyu\x12\x13.StartRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x07stopRyu\x12\x12.StopRyuServiceMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x43\n\x12getRyuManagersInfo\x12\x16.GetRyuManagersInfoMsg\x1a\x13.RyuManagersInfoDTO\"\x00\x12<\n\x0estopSnortIdses\x12\x12.StopSnortIdsesMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12X\n\x1cstopSnortIdsesMonitorThreads\x12 .StopSnortIdsesMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x35\n\x0cstopSnortIds\x12\r.StopSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12R\n\x19stopSnortIdsMonitorThread\x12\x1d.StopSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x37\n\rstartSnortIds\x12\x0e.StartSnortMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12V\n\x1bstartSnortIdsMonitorThreads\x12\x1f.StartSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astartSnortIdsMonitorThread\x12\x1e.StartSnortIdsMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15startSnortIdsManagers\x12\x19.StartSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14stopSnortIdsManagers\x12\x18.StopSnortIdsManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12H\n\x14startSnortIdsManager\x12\x18.StartSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13stopSnortIdsManager\x12\x17.StopSnortIdsManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12T\n\x1astopSnortIdsMonitorThreads\x12\x1e.StopSnortIdsMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12m\n getSnortIdsMonitorThreadStatuses\x12$.GetSnortIdsMonitorThreadStatusesMsg\x1a!.SnortIdsMonitorThreadStatusesDTO\"\x00\x12R\n\x17getSnortIdsManagersInfo\x12\x1b.GetSnortIdsManagersInfoMsg\x1a\x18.SnortIdsManagersInfoDTO\"\x00\x12=\n\x10getExecutionInfo\x12\x14.GetExecutionInfoMsg\x1a\x11.ExecutionInfoDTO\"\x00\x12?\n\x11listKibanaTunnels\x12\x15.ListKibanaTunnelsMsg\x1a\x11.KibanaTunnelsDTO\"\x00\x12\x44\n\x12\x63reateKibanaTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0elistRyuTunnels\x12\x12.ListRyuTunnelsMsg\x1a\x0e.RyuTunnelsDTO\"\x00\x12\x41\n\x0f\x63reateRyuTunnel\x12\x16.CreateKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12removeKibanaTunnel\x12\x16.RemoveKibanaTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fremoveRyuTunnel\x12\x13.RemoveRyuTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11list5GCoreTunnels\x12\x15.List5GCoreTunnelsMsg\x1a\x14.FiveGCoreTunnelsDTO\"\x00\x12\x44\n\x12\x63reate5GCoreTunnel\x12\x16.Create5GCoreTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12remove5GCoreTunnel\x12\x16.Remove5GCoreTunnelMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16stopHostMonitorThreads\x12\x1a.StopHostMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stopHostMonitorThread\x12\x19.StopHostMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x0fstartRyuMonitor\x12\x19.StartRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x0estopRyuMonitor\x12\x18.StopRyuMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12<\n\x14getRyuControllerLogs\x12\x18.GetRyuControllerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getRyuManagerLogs\x12\x15.GetRyuManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12(\n\ngetElkLogs\x12\x0e.GetElkLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x36\n\x11getElkManagerLogs\x12\x15.GetElkManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getTrafficManagerLogs\x12\x19.GetTrafficManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12getHostManagerLogs\x12\x16.GetHostManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetOSSECIdsLogs\x12\x13.GetOSSECIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getOSSECIdsManagerLogsMsg\x12\x1a.GetOSSECIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x32\n\x0fgetSnortIdsLogs\x12\x13.GetSnortIdsLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x43\n\x19getSnortIdsManagerLogsMsg\x12\x1a.GetSnortIdsManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12,\n\x0cgetKafkaLogs\x12\x10.GetKafkaLogsMsg\x1a\x08.LogsDTO\"\x00\x12:\n\x13getKafkaManagerLogs\x12\x17.GetKafkaManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12?\n\x17getClientManagerLogsMsg\x12\x18.GetClientManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x34\n\x10getContainerLogs\x12\x14.GetContainerLogsMsg\x1a\x08.LogsDTO\"\x00\x12>\n\x15getClusterManagerLogs\x12\x19.GetClusterManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12^\n\x1agetExecutionTimeSeriesData\x12\x1e.GetExecutionTimeSeriesDataMsg\x1a\x1e.EmulationMetricsTimeSeriesDTO\"\x00\x12\x42\n\x11startSparkServers\x12\x15.StartSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stopSparkServers\x12\x14.StopSparkServersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10startSparkServer\x12\x14.StartSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstopSparkServer\x12\x13.StopSparkServerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08\x63heckPid\x12\x0c.CheckPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12.\n\x07stopPid\x12\x0b.StopPidMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x46\n\x13start5GCoreManagers\x12\x17.Start5GCoreManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12stop5GCoreManagers\x12\x16.Stop5GCoreManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x44\n\x12start5GCoreManager\x12\x16.Start5GCoreManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11stop5GCoreManager\x12\x15.Stop5GCoreManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0bstop5GCores\x12\x0f.Stop5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x38\n\x0cstart5GCores\x12\x10.Start5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0binit5GCores\x12\x0f.Init5GCoresMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstop5GCore\x12\x0e.Stop5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0bstart5GCore\x12\x0f.Start5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\ninit5GCore\x12\x0e.Init5GCoreMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11start5GCUManagers\x12\x15.Start5GCUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stop5GCUManagers\x12\x14.Stop5GCUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10start5GCUManager\x12\x14.Start5GCUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstop5GCUManager\x12\x13.Stop5GCUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GCUs\x12\r.Stop5GCUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GCUs\x12\x0e.Start5GCUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tinit5GCUs\x12\r.Init5GCUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GCU\x12\x0c.Stop5GCUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GCU\x12\r.Start5GCUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08init5GCU\x12\x0c.Init5GCUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x42\n\x11start5GDUManagers\x12\x15.Start5GDUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10stop5GDUManagers\x12\x14.Stop5GDUManagersMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12@\n\x10start5GDUManager\x12\x14.Start5GDUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12>\n\x0fstop5GDUManager\x12\x13.Stop5GDUManagerMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GDUs\x12\r.Stop5GDUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GDUs\x12\x0e.Start5GDUsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GDU\x12\x0c.Stop5GDUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GDU\x12\r.Start5GDUMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstop5GUEs\x12\r.Stop5GUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\nstart5GUEs\x12\x0e.Start5GUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x30\n\x08stop5GUE\x12\x0c.Stop5GUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x32\n\tstart5GUE\x12\r.Start5GUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x36\n\x0binit5GDUUEs\x12\x0f.Init5GDUUEsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12\x34\n\ninit5GDUUE\x12\x0e.Init5GDUUEMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12O\n\x15get5GCoreManagersInfo\x12\x19.Get5GCoreManagersInfoMsg\x1a\x19.FiveGCoreManagersInfoDTO\"\x00\x12I\n\x13get5GCUManagersInfo\x12\x17.Get5GCUManagersInfoMsg\x1a\x17.FiveGCUManagersInfoDTO\"\x00\x12I\n\x13get5GDUManagersInfo\x12\x17.Get5GDUManagersInfoMsg\x1a\x17.FiveGDUManagersInfoDTO\"\x00\x12<\n\x14get5GCoreManagerLogs\x12\x18.Get5GCoreManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12get5GCUManagerLogs\x12\x16.Get5GCUManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12\x38\n\x12get5GDUManagerLogs\x12\x16.Get5GDUManagerLogsMsg\x1a\x08.LogsDTO\"\x00\x12.\n\rget5GCoreLogs\x12\x11.Get5GCoreLogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GCULogs\x12\x0f.Get5GCULogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GDULogs\x12\x0f.Get5GDULogsMsg\x1a\x08.LogsDTO\"\x00\x12*\n\x0bget5GUELogs\x12\x0f.Get5GUELogsMsg\x1a\x08.LogsDTO\"\x00\x12R\n\x19start5GCoreMonitorThreads\x12\x1d.Start5GCoreMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18start5GCoreMonitorThread\x12\x1c.Start5GCoreMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12P\n\x18stop5GCoreMonitorThreads\x12\x1c.Stop5GCoreMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17stop5GCoreMonitorThread\x12\x1b.Stop5GCoreMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17start5GCUMonitorThreads\x12\x1b.Start5GCUMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16start5GCUMonitorThread\x12\x1a.Start5GCUMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16stop5GCUMonitorThreads\x12\x1a.Stop5GCUMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stop5GCUMonitorThread\x12\x19.Stop5GCUMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12N\n\x17start5GDUMonitorThreads\x12\x1b.Start5GDUMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16start5GDUMonitorThread\x12\x1a.Start5GDUMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12L\n\x16stop5GDUMonitorThreads\x12\x1a.Stop5GDUMonitorThreadsMsg\x1a\x14.OperationOutcomeDTO\"\x00\x12J\n\x15stop5GDUMonitorThread\x12\x19.Stop5GDUMonitorThreadMsg\x1a\x14.OperationOutcomeDTO\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cluster_manager_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STOPPIDMSG']._serialized_start=25
  _globals['_STOPPIDMSG']._serialized_end=50
  _globals['_CHECKPIDMSG']._serialized_start=52
  _globals['_CHECKPIDMSG']._serialized_end=78
  _globals['_STARTSPARKSERVERMSG']._serialized_start=80
  _globals['_STARTSPARKSERVERMSG']._serialized_end=163
  _globals['_STOPSPARKSERVERMSG']._serialized_start=165
  _globals['_STOPSPARKSERVERMSG']._serialized_end=247
  _globals['_STARTSPARKSERVERSMSG']._serialized_start=249
  _globals['_STARTSPARKSERVERSMSG']._serialized_end=312
  _globals['_STOPSPARKSERVERSMSG']._serialized_start=314
  _globals['_STOPSPARKSERVERSMSG']._serialized_end=376
  _globals['_GETEXECUTIONTIMESERIESDATAMSG']._serialized_start=378
  _globals['_GETEXECUTIONTIMESERIESDATAMSG']._serialized_end=467
  _globals['_EMULATIONMETRICSTIMESERIESDTO']._serialized_start=470
  _globals['_EMULATIONMETRICSTIMESERIESDTO']._serialized_end=2900
  _globals['_AVGPORTSTATISTICDICT']._serialized_start=2902
  _globals['_AVGPORTSTATISTICDICT']._serialized_end=2973
  _globals['_AGGFLOWSTATISTICDICT']._serialized_start=2975
  _globals['_AGGFLOWSTATISTICDICT']._serialized_end=3046
  _globals['_AVGFLOWSTATISTICDICT']._serialized_start=3048
  _globals['_AVGFLOWSTATISTICDICT']._serialized_end=3119
  _globals['_PORTSTATISTICDICT']._serialized_start=3121
  _globals['_PORTSTATISTICDICT']._serialized_end=3186
  _globals['_FLOWSTATISTICDICT']._serialized_start=3188
  _globals['_FLOWSTATISTICDICT']._serialized_end=3253
  _globals['_OSSECIDSALERTCOUNTERSDICT']._serialized_start=3255
  _globals['_OSSECIDSALERTCOUNTERSDICT']._serialized_end=3336
  _globals['_HOSTMETRICSDICT']._serialized_start=3338
  _globals['_HOSTMETRICSDICT']._serialized_end=3403
  _globals['_DOCKERSTATSDICT']._serialized_start=3405
  _globals['_DOCKERSTATSDICT']._serialized_end=3466
  _globals['_AVGPORTSTATISTICDTO']._serialized_start=3469
  _globals['_AVGPORTSTATISTICDTO']._serialized_end=4041
  _globals['_AVGFLOWSTATISTICDTO']._serialized_start=4044
  _globals['_AVGFLOWSTATISTICDTO']._serialized_end=4315
  _globals['_AGGFLOWSTATISTICDTO']._serialized_start=4318
  _globals['_AGGFLOWSTATISTICDTO']._serialized_end=4456
  _globals['_PORTSTATISTICDTO']._serialized_start=4459
  _globals['_PORTSTATISTICDTO']._serialized_end=4962
  _globals['_FLOWSTATISTICDTO']._serialized_start=4965
  _globals['_FLOWSTATISTICDTO']._serialized_end=5257
  _globals['_OSSECIDSALERTCOUNTERSDTO']._serialized_start=5260
  _globals['_OSSECIDSALERTCOUNTERSDTO']._serialized_end=5457
  _globals['_SNORTIDSALERTCOUNTERSDTO']._serialized_start=5460
  _globals['_SNORTIDSALERTCOUNTERSDTO']._serialized_end=5641
  _globals['_SNORTIDSIPALERTCOUNTERSDICT']._serialized_start=5643
  _globals['_SNORTIDSIPALERTCOUNTERSDICT']._serialized_end=5728
  _globals['_SNORTIDSALERTCOUNTERSDICT']._serialized_start=5730
  _globals['_SNORTIDSALERTCOUNTERSDICT']._serialized_end=5811
  _globals['_SNORTIDSRULECOUNTERSDICT']._serialized_start=5813
  _globals['_SNORTIDSRULECOUNTERSDICT']._serialized_end=5892
  _globals['_SNORTIDSIPALERTCOUNTERSDTO']._serialized_start=5895
  _globals['_SNORTIDSIPALERTCOUNTERSDTO']._serialized_end=6096
  _globals['_SNORTIDSRULECOUNTERSDTO']._serialized_start=6098
  _globals['_SNORTIDSRULECOUNTERSDTO']._serialized_end=6192
  _globals['_EMULATIONATTACKERACTIONDTO']._serialized_start=6195
  _globals['_EMULATIONATTACKERACTIONDTO']._serialized_end=6439
  _globals['_EMULATIONDEFENDERACTIONDTO']._serialized_start=6442
  _globals['_EMULATIONDEFENDERACTIONDTO']._serialized_end=6645
  _globals['_HOSTMETRICSDATADTO']._serialized_start=6648
  _globals['_HOSTMETRICSDATADTO']._serialized_end=6854
  _globals['_DOCKERSTATSDTO']._serialized_start=6857
  _globals['_DOCKERSTATSDTO']._serialized_end=7105
  _globals['_CLIENTPOPULATIONMETRICSDTO']._serialized_start=7107
  _globals['_CLIENTPOPULATIONMETRICSDTO']._serialized_end=7216
  _globals['_GETCLUSTERMANAGERLOGSMSG']._serialized_start=7218
  _globals['_GETCLUSTERMANAGERLOGSMSG']._serialized_end=7244
  _globals['_GETCONTAINERLOGSMSG']._serialized_start=7246
  _globals['_GETCONTAINERLOGSMSG']._serialized_end=7329
  _globals['_GETCLIENTMANAGERLOGSMSG']._serialized_start=7331
  _globals['_GETCLIENTMANAGERLOGSMSG']._serialized_end=7397
  _globals['_GETKAFKAMANAGERLOGSMSG']._serialized_start=7399
  _globals['_GETKAFKAMANAGERLOGSMSG']._serialized_end=7464
  _globals['_GETKAFKALOGSMSG']._serialized_start=7466
  _globals['_GETKAFKALOGSMSG']._serialized_end=7524
  _globals['_GETSNORTIDSLOGSMSG']._serialized_start=7526
  _globals['_GETSNORTIDSLOGSMSG']._serialized_end=7608
  _globals['_GETSNORTIDSMANAGERLOGSMSG']._serialized_start=7610
  _globals['_GETSNORTIDSMANAGERLOGSMSG']._serialized_end=7699
  _globals['_GETOSSECIDSMANAGERLOGSMSG']._serialized_start=7701
  _globals['_GETOSSECIDSMANAGERLOGSMSG']._serialized_end=7790
  _globals['_GETOSSECIDSLOGSMSG']._serialized_start=7792
  _globals['_GETOSSECIDSLOGSMSG']._serialized_end=7874
  _globals['_GETHOSTMANAGERLOGSMSG']._serialized_start=7876
  _globals['_GETHOSTMANAGERLOGSMSG']._serialized_end=7961
  _globals['_GETTRAFFICMANAGERLOGSMSG']._serialized_start=7963
  _globals['_GETTRAFFICMANAGERLOGSMSG']._serialized_end=8051
  _globals['_GETELKMANAGERLOGSMSG']._serialized_start=8053
  _globals['_GETELKMANAGERLOGSMSG']._serialized_end=8116
  _globals['_GETELKLOGSMSG']._serialized_start=8118
  _globals['_GETELKLOGSMSG']._serialized_end=8174
  _globals['_GETRYUMANAGERLOGSMSG']._serialized_start=8176
  _globals['_GETRYUMANAGERLOGSMSG']._serialized_end=8239
  _globals['_GETRYUCONTROLLERLOGSMSG']._serialized_start=8241
  _globals['_GETRYUCONTROLLERLOGSMSG']._serialized_end=8307
  _globals['_STOPRYUMONITORTHREADMSG']._serialized_start=8309
  _globals['_STOPRYUMONITORTHREADMSG']._serialized_end=8375
  _globals['_STARTRYUMONITORTHREADMSG']._serialized_start=8377
  _globals['_STARTRYUMONITORTHREADMSG']._serialized_end=8444
  _globals['_STOPHOSTMONITORTHREADSMSG']._serialized_start=8446
  _globals['_STOPHOSTMONITORTHREADSMSG']._serialized_end=8514
  _globals['_STOPHOSTMONITORTHREADMSG']._serialized_start=8516
  _globals['_STOPHOSTMONITORTHREADMSG']._serialized_end=8604
  _globals['_REMOVEKIBANATUNNELMSG']._serialized_start=8606
  _globals['_REMOVEKIBANATUNNELMSG']._serialized_end=8670
  _globals['_CREATEKIBANATUNNELMSG']._serialized_start=8672
  _globals['_CREATEKIBANATUNNELMSG']._serialized_end=8736
  _globals['_LISTKIBANATUNNELSMSG']._serialized_start=8738
  _globals['_LISTKIBANATUNNELSMSG']._serialized_end=8760
  _globals['_KIBANATUNNELSDTO']._serialized_start=8762
  _globals['_KIBANATUNNELSDTO']._serialized_end=8815
  _globals['_KIBANATUNNELDTO']._serialized_start=8817
  _globals['_KIBANATUNNELDTO']._serialized_end=8901
  _globals['_REMOVE5GCORETUNNELMSG']._serialized_start=8903
  _globals['_REMOVE5GCORETUNNELMSG']._serialized_end=8967
  _globals['_CREATE5GCORETUNNELMSG']._serialized_start=8969
  _globals['_CREATE5GCORETUNNELMSG']._serialized_end=9033
  _globals['_LIST5GCORETUNNELSMSG']._serialized_start=9035
  _globals['_LIST5GCORETUNNELSMSG']._serialized_end=9057
  _globals['_FIVEGCORETUNNELSDTO']._serialized_start=9059
  _globals['_FIVEGCORETUNNELSDTO']._serialized_end=9118
  _globals['_FIVEGCORETUNNELDTO']._serialized_start=9120
  _globals['_FIVEGCORETUNNELDTO']._serialized_end=9207
  _globals['_REMOVERYUTUNNELMSG']._serialized_start=9209
  _globals['_REMOVERYUTUNNELMSG']._serialized_end=9270
  _globals['_CREATERYUTUNNELMSG']._serialized_start=9272
  _globals['_CREATERYUTUNNELMSG']._serialized_end=9333
  _globals['_LISTRYUTUNNELSMSG']._serialized_start=9335
  _globals['_LISTRYUTUNNELSMSG']._serialized_end=9354
  _globals['_RYUTUNNELSDTO']._serialized_start=9356
  _globals['_RYUTUNNELSDTO']._serialized_end=9403
  _globals['_RYUTUNNELDTO']._serialized_start=9405
  _globals['_RYUTUNNELDTO']._serialized_end=9486
  _globals['_SNORTIDSMONITORTHREADSTATUSESDTO']._serialized_start=9488
  _globals['_SNORTIDSMONITORTHREADSTATUSESDTO']._serialized_end=9568
  _globals['_GETSNORTIDSMANAGERSINFOMSG']._serialized_start=9570
  _globals['_GETSNORTIDSMANAGERSINFOMSG']._serialized_end=9639
  _globals['_GETSNORTIDSMONITORTHREADSTATUSESMSG']._serialized_start=9641
  _globals['_GETSNORTIDSMONITORTHREADSTATUSESMSG']._serialized_end=9719
  _globals['_STOPSNORTIDSMONITORTHREADSMSG']._serialized_start=9721
  _globals['_STOPSNORTIDSMONITORTHREADSMSG']._serialized_end=9793
  _globals['_STOPSNORTIDSMANAGERMSG']._serialized_start=9795
  _globals['_STOPSNORTIDSMANAGERMSG']._serialized_end=9881
  _globals['_STARTSNORTIDSMANAGERMSG']._serialized_start=9883
  _globals['_STARTSNORTIDSMANAGERMSG']._serialized_end=9970
  _globals['_STOPSNORTIDSMANAGERSMSG']._serialized_start=9972
  _globals['_STOPSNORTIDSMANAGERSMSG']._serialized_end=10038
  _globals['_STARTSNORTIDSMANAGERSMSG']._serialized_start=10040
  _globals['_STARTSNORTIDSMANAGERSMSG']._serialized_end=10107
  _globals['_STARTSNORTMSG']._serialized_start=10109
  _globals['_STARTSNORTMSG']._serialized_end=10186
  _globals['_STARTSNORTIDSMONITORTHREADMSG']._serialized_start=10188
  _globals['_STARTSNORTIDSMONITORTHREADMSG']._serialized_end=10281
  _globals['_STARTSNORTIDSMONITORTHREADSMSG']._serialized_start=10283
  _globals['_STARTSNORTIDSMONITORTHREADSMSG']._serialized_end=10356
  _globals['_STOPSNORTMSG']._serialized_start=10358
  _globals['_STOPSNORTMSG']._serialized_end=10434
  _globals['_STOPSNORTIDSMONITORTHREADMSG']._serialized_start=10436
  _globals['_STOPSNORTIDSMONITORTHREADMSG']._serialized_end=10528
  _globals['_STOPSNORTIDSESMSG']._serialized_start=10530
  _globals['_STOPSNORTIDSESMSG']._serialized_end=10590
  _globals['_STOPSNORTIDSESMONITORTHREADSMSG']._serialized_start=10592
  _globals['_STOPSNORTIDSESMONITORTHREADSMSG']._serialized_end=10666
  _globals['_GETRYUMANAGERSINFOMSG']._serialized_start=10668
  _globals['_GETRYUMANAGERSINFOMSG']._serialized_end=10732
  _globals['_STOPRYUMONITORSERVICEMSG']._serialized_start=10734
  _globals['_STOPRYUMONITORSERVICEMSG']._serialized_end=10801
  _globals['_STARTRYUMONITORSERVICEMSG']._serialized_start=10803
  _globals['_STARTRYUMONITORSERVICEMSG']._serialized_end=10871
  _globals['_STOPRYUSERVICEMSG']._serialized_start=10873
  _globals['_STOPRYUSERVICEMSG']._serialized_end=10933
  _globals['_STARTRYUSERVICEMSG']._serialized_start=10935
  _globals['_STARTRYUSERVICEMSG']._serialized_end=10996
  _globals['_GETRYUSERVICESTATUSMSG']._serialized_start=10998
  _globals['_GETRYUSERVICESTATUSMSG']._serialized_end=11063
  _globals['_STOPRYUMANAGERMSG']._serialized_start=11065
  _globals['_STOPRYUMANAGERMSG']._serialized_end=11125
  _globals['_STARTRYUMANAGERMSG']._serialized_start=11127
  _globals['_STARTRYUMANAGERMSG']._serialized_end=11188
  _globals['_GETOSSECIDSMANAGERSINFOMSG']._serialized_start=11190
  _globals['_GETOSSECIDSMANAGERSINFOMSG']._serialized_end=11259
  _globals['_OSSECIDSMONITORTHREADSTATUSESDTO']._serialized_start=11261
  _globals['_OSSECIDSMONITORTHREADSTATUSESDTO']._serialized_end=11341
  _globals['_GETOSSECIDSMONITORTHREADSTATUSESMSG']._serialized_start=11343
  _globals['_GETOSSECIDSMONITORTHREADSTATUSESMSG']._serialized_end=11421
  _globals['_STOPOSSECIDSMONITORTHREADSMSG']._serialized_start=11423
  _globals['_STOPOSSECIDSMONITORTHREADSMSG']._serialized_end=11495
  _globals['_STOPOSSECIDSMONITORTHREADMSG']._serialized_start=11497
  _globals['_STOPOSSECIDSMONITORTHREADMSG']._serialized_end=11589
  _globals['_STARTOSSECIDSMONITORTHREADMSG']._serialized_start=11591
  _globals['_STARTOSSECIDSMONITORTHREADMSG']._serialized_end=11684
  _globals['_STOPOSSECIDSMANAGER']._serialized_start=11686
  _globals['_STOPOSSECIDSMANAGER']._serialized_end=11769
  _globals['_STARTOSSECIDSMANAGER']._serialized_start=11771
  _globals['_STARTOSSECIDSMANAGER']._serialized_end=11855
  _globals['_STOPOSSECIDSMANAGERS']._serialized_start=11857
  _globals['_STOPOSSECIDSMANAGERS']._serialized_end=11920
  _globals['_STARTOSSECIDSMANAGERS']._serialized_start=11922
  _globals['_STARTOSSECIDSMANAGERS']._serialized_end=11986
  _globals['_STARTOSSECIDSMSG']._serialized_start=11988
  _globals['_STARTOSSECIDSMSG']._serialized_end=12068
  _globals['_STOPOSSECIDSMSG']._serialized_start=12070
  _globals['_STOPOSSECIDSMSG']._serialized_end=12149
  _globals['_STARTOSSECIDSESMSG']._serialized_start=12151
  _globals['_STARTOSSECIDSESMSG']._serialized_end=12212
  _globals['_STOPOSSECIDSESMSG']._serialized_start=12214
  _globals['_STOPOSSECIDSESMSG']._serialized_end=12274
  _globals['_GETKAFKAMANAGERSINFOMSG']._serialized_start=12276
  _globals['_GETKAFKAMANAGERSINFOMSG']._serialized_end=12342
  _globals['_STARTKAFKASERVERMSG']._serialized_start=12344
  _globals['_STARTKAFKASERVERMSG']._serialized_end=12406
  _globals['_STOPKAFKASERVERMSG']._serialized_start=12408
  _globals['_STOPKAFKASERVERMSG']._serialized_end=12469
  _globals['_GETKAFKAMANAGERSTATUSMSG']._serialized_start=12471
  _globals['_GETKAFKAMANAGERSTATUSMSG']._serialized_end=12538
  _globals['_CREATEKAFKATOPICSMSG']._serialized_start=12540
  _globals['_CREATEKAFKATOPICSMSG']._serialized_end=12603
  _globals['_STOPKAFKAMANAGERMSG']._serialized_start=12605
  _globals['_STOPKAFKAMANAGERMSG']._serialized_end=12667
  _globals['_STARTKAFKAMANAGERMSG']._serialized_start=12669
  _globals['_STARTKAFKAMANAGERMSG']._serialized_end=12732
  _globals['_GETHOSTMANAGERSINFOMSG']._serialized_start=12734
  _globals['_GETHOSTMANAGERSINFOMSG']._serialized_end=12799
  _globals['_GETHOSTMONITORTHREADSSTATUSESMSG']._serialized_start=12801
  _globals['_GETHOSTMONITORTHREADSSTATUSESMSG']._serialized_end=12876
  _globals['_APPLYFILEBEATCONFIGMSG']._serialized_start=12878
  _globals['_APPLYFILEBEATCONFIGMSG']._serialized_end=12964
  _globals['_APPLYPACKETBEATCONFIGMSG']._serialized_start=12966
  _globals['_APPLYPACKETBEATCONFIGMSG']._serialized_end=13054
  _globals['_APPLYMETRICBEATCONFIGMSG']._serialized_start=13056
  _globals['_APPLYMETRICBEATCONFIGMSG']._serialized_end=13144
  _globals['_APPLYHEARTBEATCONFIGMSG']._serialized_start=13146
  _globals['_APPLYHEARTBEATCONFIGMSG']._serialized_end=13233
  _globals['_STOPFILEBEATMSG']._serialized_start=13235
  _globals['_STOPFILEBEATMSG']._serialized_end=13314
  _globals['_STOPPACKETBEATMSG']._serialized_start=13316
  _globals['_STOPPACKETBEATMSG']._serialized_end=13397
  _globals['_STOPMETRICBEATMSG']._serialized_start=13399
  _globals['_STOPMETRICBEATMSG']._serialized_end=13480
  _globals['_STOPHEARTBEATMSG']._serialized_start=13482
  _globals['_STOPHEARTBEATMSG']._serialized_end=13562
  _globals['_STARTFILEBEATMSG']._serialized_start=13564
  _globals['_STARTFILEBEATMSG']._serialized_end=13666
  _globals['_STARTPACKETBEATMSG']._serialized_start=13668
  _globals['_STARTPACKETBEATMSG']._serialized_end=13772
  _globals['_STARTMETRICBEATMSG']._serialized_start=13774
  _globals['_STARTMETRICBEATMSG']._serialized_end=13878
  _globals['_STARTHEARTBEATMSG']._serialized_start=13880
  _globals['_STARTHEARTBEATMSG']._serialized_end=13983
  _globals['_STARTHOSTMONITORTHREADMSG']._serialized_start=13985
  _globals['_STARTHOSTMONITORTHREADMSG']._serialized_end=14074
  _globals['_STOPHEARTBEATSMSG']._serialized_start=14076
  _globals['_STOPHEARTBEATSMSG']._serialized_end=14136
  _globals['_STOPPACKETBEATSMSG']._serialized_start=14138
  _globals['_STOPPACKETBEATSMSG']._serialized_end=14199
  _globals['_STOPFILEBEATSMSG']._serialized_start=14201
  _globals['_STOPFILEBEATSMSG']._serialized_end=14260
  _globals['_STOPMETRICBEATSMSG']._serialized_start=14262
  _globals['_STOPMETRICBEATSMSG']._serialized_end=14323
  _globals['_STARTHOSTMONITORTHREADSMSG']._serialized_start=14325
  _globals['_STARTHOSTMONITORTHREADSMSG']._serialized_end=14394
  _globals['_STOPHOSTMANAGERMSG']._serialized_start=14396
  _globals['_STOPHOSTMANAGERMSG']._serialized_end=14478
  _globals['_STARTHOSTMANAGERMSG']._serialized_start=14480
  _globals['_STARTHOSTMANAGERMSG']._serialized_end=14563
  _globals['_STOPHOSTMANAGERSMSG']._serialized_start=14565
  _globals['_STOPHOSTMANAGERSMSG']._serialized_end=14627
  _globals['_EXECUTIONINFODTO']._serialized_start=14630
  _globals['_EXECUTIONINFODTO']._serialized_end=15490
  _globals['_RYUMANAGERSINFODTO']._serialized_start=15493
  _globals['_RYUMANAGERSINFODTO']._serialized_end=15722
  _globals['_RYUMANAGERSTATUSDTO']._serialized_start=15725
  _globals['_RYUMANAGERSTATUSDTO']._serialized_end=15905
  _globals['_HOSTMANAGERSINFODTO']._serialized_start=15908
  _globals['_HOSTMANAGERSINFODTO']._serialized_end=16083
  _globals['_HOSTMANAGERSTATUSESDTO']._serialized_start=16085
  _globals['_HOSTMANAGERSTATUSESDTO']._serialized_end=16161
  _globals['_HOSTMANAGERSTATUSDTO']._serialized_start=16164
  _globals['_HOSTMANAGERSTATUSDTO']._serialized_end=16332
  _globals['_KAFKAMANAGERSINFODTO']._serialized_start=16335
  _globals['_KAFKAMANAGERSINFODTO']._serialized_end=16507
  _globals['_KAFKASTATUSDTO']._serialized_start=16509
  _globals['_KAFKASTATUSDTO']._serialized_end=16558
  _globals['_OSSECIDSMANAGERSINFODTO']._serialized_start=16561
  _globals['_OSSECIDSMANAGERSINFODTO']._serialized_end=16745
  _globals['_OSSECIDSSTATUSDTO']._serialized_start=16747
  _globals['_OSSECIDSSTATUSDTO']._serialized_end=16818
  _globals['_SNORTIDSMANAGERSINFODTO']._serialized_start=16821
  _globals['_SNORTIDSMANAGERSINFODTO']._serialized_end=17005
  _globals['_SNORTIDSSTATUSDTO']._serialized_start=17007
  _globals['_SNORTIDSSTATUSDTO']._serialized_end=17078
  _globals['_GETEXECUTIONINFOMSG']._serialized_start=17080
  _globals['_GETEXECUTIONINFOMSG']._serialized_end=17142
  _globals['_STOPCONTAINERSOFEXECUTIONMSG']._serialized_start=17144
  _globals['_STOPCONTAINERSOFEXECUTIONMSG']._serialized_end=17215
  _globals['_RUNCONTAINERMSG']._serialized_start=17217
  _globals['_RUNCONTAINERMSG']._serialized_end=17338
  _globals['_STARTCONTAINERSOFEXECUTIONMSG']._serialized_start=17340
  _globals['_STARTCONTAINERSOFEXECUTIONMSG']._serialized_end=17412
  _globals['_GETELKMANAGERSINFOMSG']._serialized_start=17414
  _globals['_GETELKMANAGERSINFOMSG']._serialized_end=17478
  _globals['_ELKMANAGERSINFODTO']._serialized_start=17481
  _globals['_ELKMANAGERSINFODTO']._serialized_end=17696
  _globals['_STOPLOGSTASHSERVICEMSG']._serialized_start=17698
  _globals['_STOPLOGSTASHSERVICEMSG']._serialized_end=17763
  _globals['_STARTLOGSTASHSERVICEMSG']._serialized_start=17765
  _globals['_STARTLOGSTASHSERVICEMSG']._serialized_end=17831
  _globals['_STOPKIBANASERVICEMSG']._serialized_start=17833
  _globals['_STOPKIBANASERVICEMSG']._serialized_end=17896
  _globals['_STARTKIBANASERVICEMSG']._serialized_start=17898
  _globals['_STARTKIBANASERVICEMSG']._serialized_end=17962
  _globals['_STOPELASTICSERVICEMSG']._serialized_start=17964
  _globals['_STOPELASTICSERVICEMSG']._serialized_end=18028
  _globals['_STARTELASTICSERVICEMSG']._serialized_start=18030
  _globals['_STARTELASTICSERVICEMSG']._serialized_end=18095
  _globals['_STOPELKSTACKMSG']._serialized_start=18097
  _globals['_STOPELKSTACKMSG']._serialized_end=18155
  _globals['_ELKSTATUSDTO']._serialized_start=18157
  _globals['_ELKSTATUSDTO']._serialized_end=18243
  _globals['_GETELKSTACKSTATUSMSG']._serialized_start=18245
  _globals['_GETELKSTACKSTATUSMSG']._serialized_end=18308
  _globals['_STOPELKMANAGERMSG']._serialized_start=18310
  _globals['_STOPELKMANAGERMSG']._serialized_end=18370
  _globals['_STARTELKMANAGERMSG']._serialized_start=18372
  _globals['_STARTELKMANAGERMSG']._serialized_end=18433
  _globals['_GETDOCKERSTATSMANAGERSINFOMSG']._serialized_start=18435
  _globals['_GETDOCKERSTATSMANAGERSINFOMSG']._serialized_end=18507
  _globals['_DOCKERSTATSMANAGERSINFODTO']._serialized_start=18510
  _globals['_DOCKERSTATSMANAGERSINFODTO']._serialized_end=18713
  _globals['_REMOVEALLDOCKERNETWORKSMSG']._serialized_start=18715
  _globals['_REMOVEALLDOCKERNETWORKSMSG']._serialized_end=18743
  _globals['_REMOVEDOCKERNETWORKSMSG']._serialized_start=18745
  _globals['_REMOVEDOCKERNETWORKSMSG']._serialized_end=18788
  _globals['_DOCKERSTATSMONITORSTATUSDTO']._serialized_start=18790
  _globals['_DOCKERSTATSMONITORSTATUSDTO']._serialized_end=18891
  _globals['_GETDOCKERSTATSMANAGERSTATUSMSG']._serialized_start=18893
  _globals['_GETDOCKERSTATSMANAGERSTATUSMSG']._serialized_end=18939
  _globals['_STOPDOCKERSTATSMANAGERTHREADMSG']._serialized_start=18941
  _globals['_STOPDOCKERSTATSMANAGERTHREADMSG']._serialized_end=19015
  _globals['_CREATEEMULATIONNETWORKSMSG']._serialized_start=19017
  _globals['_CREATEEMULATIONNETWORKSMSG']._serialized_end=19086
  _globals['_LISTALLSTOPPEDCONTAINERSMSG']._serialized_start=19088
  _globals['_LISTALLSTOPPEDCONTAINERSMSG']._serialized_end=19117
  _globals['_STOPPEDCONTAINERSDTO']._serialized_start=19119
  _globals['_STOPPEDCONTAINERSDTO']._serialized_end=19189
  _globals['_LISTALLRUNNINGEMULATIONSMSG']._serialized_start=19191
  _globals['_LISTALLRUNNINGEMULATIONSMSG']._serialized_end=19220
  _globals['_RUNNINGEMULATIONSDTO']._serialized_start=19222
  _globals['_RUNNINGEMULATIONSDTO']._serialized_end=19271
  _globals['_LISTALLRUNNINGCONTAINERSMSG']._serialized_start=19273
  _globals['_LISTALLRUNNINGCONTAINERSMSG']._serialized_end=19302
  _globals['_RUNNINGCONTAINERSDTO']._serialized_start=19304
  _globals['_RUNNINGCONTAINERSDTO']._serialized_end=19374
  _globals['_DOCKERCONTAINERDTO']._serialized_start=19376
  _globals['_DOCKERCONTAINERDTO']._serialized_end=19437
  _globals['_STARTCONTAINERMSG']._serialized_start=19439
  _globals['_STARTCONTAINERMSG']._serialized_end=19472
  _globals['_STARTALLSTOPPEDCONTAINERSMSG']._serialized_start=19474
  _globals['_STARTALLSTOPPEDCONTAINERSMSG']._serialized_end=19504
  _globals['_LISTALLDOCKERNETWORKSMSG']._serialized_start=19506
  _globals['_LISTALLDOCKERNETWORKSMSG']._serialized_end=19532
  _globals['_DOCKERNETWORKSDTO']._serialized_start=19534
  _globals['_DOCKERNETWORKSDTO']._serialized_end=19592
  _globals['_CONTAINERIMAGESDTO']._serialized_start=19594
  _globals['_CONTAINERIMAGESDTO']._serialized_end=19650
  _globals['_CONTAINERIMAGEDTO']._serialized_start=19652
  _globals['_CONTAINERIMAGEDTO']._serialized_end=19754
  _globals['_LISTALLCONTAINERIMAGESMSG']._serialized_start=19756
  _globals['_LISTALLCONTAINERIMAGESMSG']._serialized_end=19783
  _globals['_REMOVECONTAINERIMAGEMSG']._serialized_start=19785
  _globals['_REMOVECONTAINERIMAGEMSG']._serialized_end=19824
  _globals['_REMOVEALLCONTAINERIMAGESMSG']._serialized_start=19826
  _globals['_REMOVEALLCONTAINERIMAGESMSG']._serialized_end=19855
  _globals['_REMOVEALLSTOPPEDCONTAINERSMSG']._serialized_start=19857
  _globals['_REMOVEALLSTOPPEDCONTAINERSMSG']._serialized_end=19888
  _globals['_REMOVECONTAINERMSG']._serialized_start=19890
  _globals['_REMOVECONTAINERMSG']._serialized_end=19924
  _globals['_STOPCONTAINERMSG']._serialized_start=19926
  _globals['_STOPCONTAINERMSG']._serialized_end=19958
  _globals['_STOPALLRUNNINGCONTAINERSMSG']._serialized_start=19960
  _globals['_STOPALLRUNNINGCONTAINERSMSG']._serialized_end=19989
  _globals['_GETTRAFFICMANAGERSINFOMSG']._serialized_start=19991
  _globals['_GETTRAFFICMANAGERSINFOMSG']._serialized_end=20059
  _globals['_TRAFFICMANAGERSINFODTO']._serialized_start=20062
  _globals['_TRAFFICMANAGERSINFODTO']._serialized_end=20247
  _globals['_TRAFFICMANAGERINFODTO']._serialized_start=20249
  _globals['_TRAFFICMANAGERINFODTO']._serialized_end=20305
  _globals['_CLIENTMANAGERSINFODTO']._serialized_start=20308
  _globals['_CLIENTMANAGERSINFODTO']._serialized_end=20485
  _globals['_GETCLIENTMANAGERSINFOMSG']._serialized_start=20487
  _globals['_GETCLIENTMANAGERSINFOMSG']._serialized_end=20554
  _globals['_STARTTRAFFICGENERATORMSG']._serialized_start=20556
  _globals['_STARTTRAFFICGENERATORMSG']._serialized_end=20644
  _globals['_STOPTRAFFICGENERATORMSG']._serialized_start=20646
  _globals['_STOPTRAFFICGENERATORMSG']._serialized_end=20733
  _globals['_STOPTRAFFICGENERATORSMSG']._serialized_start=20735
  _globals['_STOPTRAFFICGENERATORSMSG']._serialized_end=20802
  _globals['_GETNUMCLIENTSDTO']._serialized_start=20805
  _globals['_GETNUMCLIENTSDTO']._serialized_end=20979
  _globals['_GETNUMACTIVECLIENTSMSG']._serialized_start=20981
  _globals['_GETNUMACTIVECLIENTSMSG']._serialized_end=21046
  _globals['_STOPCLIENTPOPULATIONMSG']._serialized_start=21048
  _globals['_STOPCLIENTPOPULATIONMSG']._serialized_end=21114
  _globals['_STOPCLIENTMANAGERMSG']._serialized_start=21116
  _globals['_STOPCLIENTMANAGERMSG']._serialized_end=21179
  _globals['_STARTCLIENTMANAGERMSG']._serialized_start=21181
  _globals['_STARTCLIENTMANAGERMSG']._serialized_end=21245
  _globals['_STOPTRAFFICMANAGERSMSG']._serialized_start=21247
  _globals['_STOPTRAFFICMANAGERSMSG']._serialized_end=21312
  _globals['_STOPTRAFFICMANAGERMSG']._serialized_start=21314
  _globals['_STOPTRAFFICMANAGERMSG']._serialized_end=21399
  _globals['_STARTTRAFFICMANAGERMSG']._serialized_start=21401
  _globals['_STARTTRAFFICMANAGERMSG']._serialized_end=21487
  _globals['_CLEANALLEXECUTIONSMSG']._serialized_start=21489
  _globals['_CLEANALLEXECUTIONSMSG']._serialized_end=21512
  _globals['_STOPALLEXECUTIONSMSG']._serialized_start=21514
  _globals['_STOPALLEXECUTIONSMSG']._serialized_end=21536
  _globals['_STOPEXECUTIONMSG']._serialized_start=21538
  _globals['_STOPEXECUTIONMSG']._serialized_end=21597
  _globals['_CLEANEXECUTIONMSG']._serialized_start=21599
  _globals['_CLEANEXECUTIONMSG']._serialized_end=21659
  _globals['_STOPALLEXECUTIONSOFEMULATIONMSG']._serialized_start=21661
  _globals['_STOPALLEXECUTIONSOFEMULATIONMSG']._serialized_end=21713
  _globals['_CLEANALLEXECUTIONSOFEMULATIONMSG']._serialized_start=21715
  _globals['_CLEANALLEXECUTIONSOFEMULATIONMSG']._serialized_end=21768
  _globals['_GETCSLELOGFILESMSG']._serialized_start=21770
  _globals['_GETCSLELOGFILESMSG']._serialized_end=21790
  _globals['_GETLOGFILEMSG']._serialized_start=21792
  _globals['_GETLOGFILEMSG']._serialized_end=21821
  _globals['_STARTCONTAINERSINEXECUTIONMSG']._serialized_start=21823
  _globals['_STARTCONTAINERSINEXECUTIONMSG']._serialized_end=21895
  _globals['_ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG']._serialized_start=21897
  _globals['_ATTACHCONTAINERSTONETWORKSINEXECUTIONMSG']._serialized_end=21980
  _globals['_INSTALLLIBRARIESMSG']._serialized_start=21982
  _globals['_INSTALLLIBRARIESMSG']._serialized_end=22044
  _globals['_APPLYKAFKACONFIGMSG']._serialized_start=22046
  _globals['_APPLYKAFKACONFIGMSG']._serialized_end=22108
  _globals['_STARTSDNCONTROLLERMSG']._serialized_start=22110
  _globals['_STARTSDNCONTROLLERMSG']._serialized_end=22174
  _globals['_APPLYRESOUCECONSTRAINTSMSG']._serialized_start=22176
  _globals['_APPLYRESOUCECONSTRAINTSMSG']._serialized_end=22245
  _globals['_CREATEOVSSWITCHESMSG']._serialized_start=22247
  _globals['_CREATEOVSSWITCHESMSG']._serialized_end=22310
  _globals['_PINGEXECUTIONMSG']._serialized_start=22312
  _globals['_PINGEXECUTIONMSG']._serialized_end=22371
  _globals['_CONFIGUREOVSMSG']._serialized_start=22373
  _globals['_CONFIGUREOVSMSG']._serialized_end=22431
  _globals['_STARTSDNCONTROLLERMONITORMSG']._serialized_start=22433
  _globals['_STARTSDNCONTROLLERMONITORMSG']._serialized_end=22504
  _globals['_CREATEUSERSMSG']._serialized_start=22506
  _globals['_CREATEUSERSMSG']._serialized_end=22563
  _globals['_CREATEVULNSMSG']._serialized_start=22565
  _globals['_CREATEVULNSMSG']._serialized_end=22622
  _globals['_CREATEFLAGSMSG']._serialized_start=22624
  _globals['_CREATEFLAGSMSG']._serialized_end=22681
  _globals['_CREATETOPOLOGYMSG']._serialized_start=22683
  _globals['_CREATETOPOLOGYMSG']._serialized_end=22743
  _globals['_STARTTRAFFICMANAGERSMSG']._serialized_start=22745
  _globals['_STARTTRAFFICMANAGERSMSG']._serialized_end=22811
  _globals['_STARTTRAFFICGENERATORSMSG']._serialized_start=22813
  _globals['_STARTTRAFFICGENERATORSMSG']._serialized_end=22881
  _globals['_STARTCLIENTPOPULATIONMSG']._serialized_start=22883
  _globals['_STARTCLIENTPOPULATIONMSG']._serialized_end=22950
  _globals['_STARTKAFKACLIENTPRODUCERMSG']._serialized_start=22952
  _globals['_STARTKAFKACLIENTPRODUCERMSG']._serialized_end=23022
  _globals['_STOPKAFKACLIENTPRODUCERMSG']._serialized_start=23024
  _globals['_STOPKAFKACLIENTPRODUCERMSG']._serialized_end=23093
  _globals['_STARTSNORTIDSESMSG']._serialized_start=23095
  _globals['_STARTSNORTIDSESMSG']._serialized_end=23156
  _globals['_STARTSNORTIDSESMONITORTHREADSMSG']._serialized_start=23158
  _globals['_STARTSNORTIDSESMONITORTHREADSMSG']._serialized_end=23233
  _globals['_STARTOSSECIDSESMSG']._serialized_start=23235
  _globals['_STARTOSSECIDSESMSG']._serialized_end=23296
  _globals['_STARTOSSECIDSESMONITORTHREADSMSG']._serialized_start=23298
  _globals['_STARTOSSECIDSESMONITORTHREADSMSG']._serialized_end=23373
  _globals['_STARTELKSTACKMSG']._serialized_start=23375
  _globals['_STARTELKSTACKMSG']._serialized_end=23434
  _globals['_STARTHOSTMANAGERSMSG']._serialized_start=23436
  _globals['_STARTHOSTMANAGERSMSG']._serialized_end=23499
  _globals['_APPLYFILEBEATCONFIGSMSG']._serialized_start=23501
  _globals['_APPLYFILEBEATCONFIGSMSG']._serialized_end=23567
  _globals['_APPLYPACKETBEATCONFIGSMSG']._serialized_start=23569
  _globals['_APPLYPACKETBEATCONFIGSMSG']._serialized_end=23637
  _globals['_APPLYMETRICBEATCONFIGSMSG']._serialized_start=23639
  _globals['_APPLYMETRICBEATCONFIGSMSG']._serialized_end=23707
  _globals['_APPLYHEARTBEATCONFIGSMSG']._serialized_start=23709
  _globals['_APPLYHEARTBEATCONFIGSMSG']._serialized_end=23776
  _globals['_STARTFILEBEATSMSG']._serialized_start=23778
  _globals['_STARTFILEBEATSMSG']._serialized_end=23860
  _globals['_STARTPACKETBEATSMSG']._serialized_start=23862
  _globals['_STARTPACKETBEATSMSG']._serialized_end=23946
  _globals['_STARTMETRICBEATSMSG']._serialized_start=23948
  _globals['_STARTMETRICBEATSMSG']._serialized_end=24032
  _globals['_STARTHEARTBEATSMSG']._serialized_start=24034
  _globals['_STARTHEARTBEATSMSG']._serialized_end=24117
  _globals['_GETDOCKERSTATSMANAGERLOGSMSG']._serialized_start=24119
  _globals['_GETDOCKERSTATSMANAGERLOGSMSG']._serialized_end=24149
  _globals['_GETPROMETHEUSLOGSMSG']._serialized_start=24151
  _globals['_GETPROMETHEUSLOGSMSG']._serialized_end=24173
  _globals['_GETNODEEXPORTERLOGSMSG']._serialized_start=24175
  _globals['_GETNODEEXPORTERLOGSMSG']._serialized_end=24199
  _globals['_GETCADVISORLOGSMSG']._serialized_start=24201
  _globals['_GETCADVISORLOGSMSG']._serialized_end=24221
  _globals['_GETPGADMINLOGSMSG']._serialized_start=24223
  _globals['_GETPGADMINLOGSMSG']._serialized_end=24242
  _globals['_GETGRAFANALOGSMSG']._serialized_start=24244
  _globals['_GETGRAFANALOGSMSG']._serialized_end=24263
  _globals['_GETNGINXLOGSMSG']._serialized_start=24265
  _globals['_GETNGINXLOGSMSG']._serialized_end=24282
  _globals['_GETDOCKERLOGSMSG']._serialized_start=24284
  _globals['_GETDOCKERLOGSMSG']._serialized_end=24302
  _globals['_GETPOSTGRESQLLOGSMSG']._serialized_start=24304
  _globals['_GETPOSTGRESQLLOGSMSG']._serialized_end=24326
  _globals['_GETFLASKLOGSMSG']._serialized_start=24328
  _globals['_GETFLASKLOGSMSG']._serialized_end=24345
  _globals['_LOGSDTO']._serialized_start=24347
  _globals['_LOGSDTO']._serialized_end=24370
  _globals['_OPERATIONOUTCOMEDTO']._serialized_start=24372
  _globals['_OPERATIONOUTCOMEDTO']._serialized_end=24410
  _globals['_GETNODESTATUSMSG']._serialized_start=24412
  _globals['_GETNODESTATUSMSG']._serialized_end=24430
  _globals['_NODESTATUSDTO']._serialized_start=24433
  _globals['_NODESTATUSDTO']._serialized_end=24740
  _globals['_SERVICESTATUSDTO']._serialized_start=24742
  _globals['_SERVICESTATUSDTO']._serialized_end=24777
  _globals['_STARTPOSTGRESQLMSG']._serialized_start=24779
  _globals['_STARTPOSTGRESQLMSG']._serialized_end=24799
  _globals['_STARTCADVISORMSG']._serialized_start=24801
  _globals['_STARTCADVISORMSG']._serialized_end=24819
  _globals['_STARTNODEEXPORTERMSG']._serialized_start=24821
  _globals['_STARTNODEEXPORTERMSG']._serialized_end=24843
  _globals['_STARTGRAFANAMSG']._serialized_start=24845
  _globals['_STARTGRAFANAMSG']._serialized_end=24862
  _globals['_STARTPROMETHEUSMSG']._serialized_start=24864
  _globals['_STARTPROMETHEUSMSG']._serialized_end=24884
  _globals['_STARTPGADMINMSG']._serialized_start=24886
  _globals['_STARTPGADMINMSG']._serialized_end=24903
  _globals['_STARTNGINXMSG']._serialized_start=24905
  _globals['_STARTNGINXMSG']._serialized_end=24920
  _globals['_STARTFLASKMSG']._serialized_start=24922
  _globals['_STARTFLASKMSG']._serialized_end=24937
  _globals['_STARTDOCKERSTATSMANAGERMSG']._serialized_start=24939
  _globals['_STARTDOCKERSTATSMANAGERMSG']._serialized_end=24967
  _globals['_STARTDOCKERSTATSMANAGERTHREADMSG']._serialized_start=24969
  _globals['_STARTDOCKERSTATSMANAGERTHREADMSG']._serialized_end=25044
  _globals['_STARTDOCKERENGINEMSG']._serialized_start=25046
  _globals['_STARTDOCKERENGINEMSG']._serialized_end=25068
  _globals['_STOPPOSTGRESQLMSG']._serialized_start=25070
  _globals['_STOPPOSTGRESQLMSG']._serialized_end=25089
  _globals['_STOPCADVISORMSG']._serialized_start=25091
  _globals['_STOPCADVISORMSG']._serialized_end=25108
  _globals['_STOPNODEEXPORTERMSG']._serialized_start=25110
  _globals['_STOPNODEEXPORTERMSG']._serialized_end=25131
  _globals['_STOPGRAFANAMSG']._serialized_start=25133
  _globals['_STOPGRAFANAMSG']._serialized_end=25149
  _globals['_STOPPROMETHEUSMSG']._serialized_start=25151
  _globals['_STOPPROMETHEUSMSG']._serialized_end=25170
  _globals['_STOPPGADMINMSG']._serialized_start=25172
  _globals['_STOPPGADMINMSG']._serialized_end=25188
  _globals['_STOPNGINXMSG']._serialized_start=25190
  _globals['_STOPNGINXMSG']._serialized_end=25204
  _globals['_STOPFLASKMSG']._serialized_start=25206
  _globals['_STOPFLASKMSG']._serialized_end=25220
  _globals['_STOPDOCKERSTATSMANAGERMSG']._serialized_start=25222
  _globals['_STOPDOCKERSTATSMANAGERMSG']._serialized_end=25249
  _globals['_STOPDOCKERENGINEMSG']._serialized_start=25251
  _globals['_STOPDOCKERENGINEMSG']._serialized_end=25272
  _globals['_START5GCOREMANAGERSMSG']._serialized_start=25274
  _globals['_START5GCOREMANAGERSMSG']._serialized_end=25339
  _globals['_STOP5GCOREMANAGERSMSG']._serialized_start=25341
  _globals['_STOP5GCOREMANAGERSMSG']._serialized_end=25405
  _globals['_START5GCOREMANAGERMSG']._serialized_start=25407
  _globals['_START5GCOREMANAGERMSG']._serialized_end=25492
  _globals['_STOP5GCOREMANAGERMSG']._serialized_start=25494
  _globals['_STOP5GCOREMANAGERMSG']._serialized_end=25578
  _globals['_STOP5GCOREMSG']._serialized_start=25580
  _globals['_STOP5GCOREMSG']._serialized_end=25657
  _globals['_STOP5GCORESMSG']._serialized_start=25659
  _globals['_STOP5GCORESMSG']._serialized_end=25716
  _globals['_START5GCOREMSG']._serialized_start=25718
  _globals['_START5GCOREMSG']._serialized_end=25796
  _globals['_START5GCORESMSG']._serialized_start=25798
  _globals['_START5GCORESMSG']._serialized_end=25856
  _globals['_INIT5GCOREMSG']._serialized_start=25858
  _globals['_INIT5GCOREMSG']._serialized_end=25935
  _globals['_INIT5GCORESMSG']._serialized_start=25937
  _globals['_INIT5GCORESMSG']._serialized_end=25994
  _globals['_START5GCUMANAGERSMSG']._serialized_start=25996
  _globals['_START5GCUMANAGERSMSG']._serialized_end=26059
  _globals['_STOP5GCUMANAGERSMSG']._serialized_start=26061
  _globals['_STOP5GCUMANAGERSMSG']._serialized_end=26123
  _globals['_START5GCUMANAGERMSG']._serialized_start=26125
  _globals['_START5GCUMANAGERMSG']._serialized_end=26208
  _globals['_STOP5GCUMANAGERMSG']._serialized_start=26210
  _globals['_STOP5GCUMANAGERMSG']._serialized_end=26292
  _globals['_STOP5GCUMSG']._serialized_start=26294
  _globals['_STOP5GCUMSG']._serialized_end=26369
  _globals['_STOP5GCUSMSG']._serialized_start=26371
  _globals['_STOP5GCUSMSG']._serialized_end=26426
  _globals['_START5GCUMSG']._serialized_start=26428
  _globals['_START5GCUMSG']._serialized_end=26504
  _globals['_START5GCUSMSG']._serialized_start=26506
  _globals['_START5GCUSMSG']._serialized_end=26562
  _globals['_INIT5GCUMSG']._serialized_start=26564
  _globals['_INIT5GCUMSG']._serialized_end=26639
  _globals['_INIT5GCUSMSG']._serialized_start=26641
  _globals['_INIT5GCUSMSG']._serialized_end=26696
  _globals['_START5GDUMANAGERSMSG']._serialized_start=26698
  _globals['_START5GDUMANAGERSMSG']._serialized_end=26761
  _globals['_STOP5GDUMANAGERSMSG']._serialized_start=26763
  _globals['_STOP5GDUMANAGERSMSG']._serialized_end=26825
  _globals['_START5GDUMANAGERMSG']._serialized_start=26827
  _globals['_START5GDUMANAGERMSG']._serialized_end=26910
  _globals['_STOP5GDUMANAGERMSG']._serialized_start=26912
  _globals['_STOP5GDUMANAGERMSG']._serialized_end=26994
  _globals['_STOP5GDUMSG']._serialized_start=26996
  _globals['_STOP5GDUMSG']._serialized_end=27071
  _globals['_STOP5GDUSMSG']._serialized_start=27073
  _globals['_STOP5GDUSMSG']._serialized_end=27128
  _globals['_START5GDUMSG']._serialized_start=27130
  _globals['_START5GDUMSG']._serialized_end=27206
  _globals['_START5GDUSMSG']._serialized_start=27208
  _globals['_START5GDUSMSG']._serialized_end=27264
  _globals['_STOP5GUEMSG']._serialized_start=27266
  _globals['_STOP5GUEMSG']._serialized_end=27341
  _globals['_STOP5GUESMSG']._serialized_start=27343
  _globals['_STOP5GUESMSG']._serialized_end=27398
  _globals['_START5GUEMSG']._serialized_start=27400
  _globals['_START5GUEMSG']._serialized_end=27476
  _globals['_START5GUESMSG']._serialized_start=27478
  _globals['_START5GUESMSG']._serialized_end=27534
  _globals['_INIT5GDUUEMSG']._serialized_start=27536
  _globals['_INIT5GDUUEMSG']._serialized_end=27613
  _globals['_INIT5GDUUESMSG']._serialized_start=27615
  _globals['_INIT5GDUUESMSG']._serialized_end=27672
  _globals['_GET5GCOREMANAGERSINFOMSG']._serialized_start=27674
  _globals['_GET5GCOREMANAGERSINFOMSG']._serialized_end=27741
  _globals['_GET5GCUMANAGERSINFOMSG']._serialized_start=27743
  _globals['_GET5GCUMANAGERSINFOMSG']._serialized_end=27808
  _globals['_GET5GDUMANAGERSINFOMSG']._serialized_start=27810
  _globals['_GET5GDUMANAGERSINFOMSG']._serialized_end=27875
  _globals['_FIVEGCOREINFODTO']._serialized_start=27878
  _globals['_FIVEGCOREINFODTO']._serialized_end=28342
  _globals['_FIVEGCUINFODTO']._serialized_start=28344
  _globals['_FIVEGCUINFODTO']._serialized_end=28417
  _globals['_FIVEGDUINFODTO']._serialized_start=28419
  _globals['_FIVEGDUINFODTO']._serialized_end=28512
  _globals['_FIVEGCOREMANAGERSINFODTO']._serialized_start=28515
  _globals['_FIVEGCOREMANAGERSINFODTO']._serialized_end=28701
  _globals['_FIVEGCUMANAGERSINFODTO']._serialized_start=28704
  _globals['_FIVEGCUMANAGERSINFODTO']._serialized_end=28882
  _globals['_FIVEGDUMANAGERSINFODTO']._serialized_start=28885
  _globals['_FIVEGDUMANAGERSINFODTO']._serialized_end=29063
  _globals['_GET5GCOREMANAGERLOGSMSG']._serialized_start=29065
  _globals['_GET5GCOREMANAGERLOGSMSG']._serialized_end=29152
  _globals['_GET5GCUMANAGERLOGSMSG']._serialized_start=29154
  _globals['_GET5GCUMANAGERLOGSMSG']._serialized_end=29239
  _globals['_GET5GDUMANAGERLOGSMSG']._serialized_start=29241
  _globals['_GET5GDUMANAGERLOGSMSG']._serialized_end=29326
  _globals['_GET5GCORELOGSMSG']._serialized_start=29328
  _globals['_GET5GCORELOGSMSG']._serialized_end=29408
  _globals['_GET5GCULOGSMSG']._serialized_start=29410
  _globals['_GET5GCULOGSMSG']._serialized_end=29488
  _globals['_GET5GDULOGSMSG']._serialized_start=29490
  _globals['_GET5GDULOGSMSG']._serialized_end=29568
  _globals['_GET5GUELOGSMSG']._serialized_start=29570
  _globals['_GET5GUELOGSMSG']._serialized_end=29648
  _globals['_START5GCOREMONITORTHREADSMSG']._serialized_start=29650
  _globals['_START5GCOREMONITORTHREADSMSG']._serialized_end=29721
  _globals['_START5GCOREMONITORTHREADMSG']._serialized_start=29723
  _globals['_START5GCOREMONITORTHREADMSG']._serialized_end=29814
  _globals['_STOP5GCOREMONITORTHREADSMSG']._serialized_start=29816
  _globals['_STOP5GCOREMONITORTHREADSMSG']._serialized_end=29886
  _globals['_STOP5GCOREMONITORTHREADMSG']._serialized_start=29888
  _globals['_STOP5GCOREMONITORTHREADMSG']._serialized_end=29978
  _globals['_START5GCUMONITORTHREADSMSG']._serialized_start=29980
  _globals['_START5GCUMONITORTHREADSMSG']._serialized_end=30049
  _globals['_START5GCUMONITORTHREADMSG']._serialized_start=30051
  _globals['_START5GCUMONITORTHREADMSG']._serialized_end=30140
  _globals['_STOP5GCUMONITORTHREADSMSG']._serialized_start=30142
  _globals['_STOP5GCUMONITORTHREADSMSG']._serialized_end=30210
  _globals['_STOP5GCUMONITORTHREADMSG']._serialized_start=30212
  _globals['_STOP5GCUMONITORTHREADMSG']._serialized_end=30300
  _globals['_START5GDUMONITORTHREADSMSG']._serialized_start=30302
  _globals['_START5GDUMONITORTHREADSMSG']._serialized_end=30371
  _globals['_START5GDUMONITORTHREADMSG']._serialized_start=30373
  _globals['_START5GDUMONITORTHREADMSG']._serialized_end=30462
  _globals['_STOP5GDUMONITORTHREADSMSG']._serialized_start=30464
  _globals['_STOP5GDUMONITORTHREADSMSG']._serialized_end=30532
  _globals['_STOP5GDUMONITORTHREADMSG']._serialized_start=30534
  _globals['_STOP5GDUMONITORTHREADMSG']._serialized_end=30622
  _globals['_FIVEGCOREAMFMETRICSDICT']._serialized_start=30624
  _globals['_FIVEGCOREAMFMETRICSDICT']._serialized_end=30701
  _globals['_FIVEGCOREAMFMETRICSDTO']._serialized_start=30704
  _globals['_FIVEGCOREAMFMETRICSDTO']._serialized_end=31645
  _globals['_FIVEGCOREHSSMETRICSDICT']._serialized_start=31647
  _globals['_FIVEGCOREHSSMETRICSDICT']._serialized_end=31724
  _globals['_FIVEGCOREHSSMETRICSDTO']._serialized_start=31727
  _globals['_FIVEGCOREHSSMETRICSDTO']._serialized_end=32855
  _globals['_FIVEGCOREMMEMETRICSDICT']._serialized_start=32857
  _globals['_FIVEGCOREMMEMETRICSDICT']._serialized_end=32934
  _globals['_FIVEGCOREMMEMETRICSDTO']._serialized_start=32937
  _globals['_FIVEGCOREMMEMETRICSDTO']._serialized_end=33276
  _globals['_FIVEGCOREPCFMETRICSDICT']._serialized_start=33278
  _globals['_FIVEGCOREPCFMETRICSDICT']._serialized_end=33355
  _globals['_FIVEGCOREPCFMETRICSDTO']._serialized_start=33358
  _globals['_FIVEGCOREPCFMETRICSDTO']._serialized_end=33879
  _globals['_FIVEGCOREPCRFMETRICSDICT']._serialized_start=33881
  _globals['_FIVEGCOREPCRFMETRICSDICT']._serialized_end=33960
  _globals['_FIVEGCOREPCRFMETRICSDTO']._serialized_start=33963
  _globals['_FIVEGCOREPCRFMETRICSDTO']._serialized_end=34595
  _globals['_FIVEGCORESMFMETRICSDICT']._serialized_start=34597
  _globals['_FIVEGCORESMFMETRICSDICT']._serialized_end=34674
  _globals['_FIVEGCORESMFMETRICSDTO']._serialized_start=34677
  _globals['_FIVEGCORESMFMETRICSDTO']._serialized_end=35812
  _globals['_FIVEGCOREUPFMETRICSDICT']._serialized_start=35814
  _globals['_FIVEGCOREUPFMETRICSDICT']._serialized_end=35891
  _globals['_FIVEGCOREUPFMETRICSDTO']._serialized_start=35894
  _globals['_FIVEGCOREUPFMETRICSDTO']._serialized_end=36483
  _globals['_FIVEGCUAPPRESOURCEUSAGEMETRICSDICT']._serialized_start=36485
  _globals['_FIVEGCUAPPRESOURCEUSAGEMETRICSDICT']._serialized_end=36584
  _globals['_FIVEGCUAPPRESOURCEUSAGEMETRICSDTO']._serialized_start=36587
  _globals['_FIVEGCUAPPRESOURCEUSAGEMETRICSDTO']._serialized_end=36731
  _globals['_FIVEGCUBUFFERPOOLMETRICSDICT']._serialized_start=36733
  _globals['_FIVEGCUBUFFERPOOLMETRICSDICT']._serialized_end=36820
  _globals['_FIVEGCUBUFFERPOOLMETRICSDTO']._serialized_start=36822
  _globals['_FIVEGCUBUFFERPOOLMETRICSDTO']._serialized_end=36903
  _globals['_FIVEGCUCPMETRICSDICT']._serialized_start=36905
  _globals['_FIVEGCUCPMETRICSDICT']._serialized_end=36976
  _globals['_FIVEGCUCPMETRICSDTO']._serialized_start=36979
  _globals['_FIVEGCUCPMETRICSDTO']._serialized_end=37844
  _globals['_FIVEGDUAPPRESOURCEUSAGEMETRICSDICT']._serialized_start=37846
  _globals['_FIVEGDUAPPRESOURCEUSAGEMETRICSDICT']._serialized_end=37945
  _globals['_FIVEGDUAPPRESOURCEUSAGEMETRICSDTO']._serialized_start=37948
  _globals['_FIVEGDUAPPRESOURCEUSAGEMETRICSDTO']._serialized_end=38092
  _globals['_FIVEGDUBUFFERPOOLMETRICSDICT']._serialized_start=38094
  _globals['_FIVEGDUBUFFERPOOLMETRICSDICT']._serialized_end=38181
  _globals['_FIVEGDUBUFFERPOOLMETRICSDTO']._serialized_start=38183
  _globals['_FIVEGDUBUFFERPOOLMETRICSDTO']._serialized_end=38264
  _globals['_FIVEGDUCELLMETRICSDICT']._serialized_start=38266
  _globals['_FIVEGDUCELLMETRICSDICT']._serialized_end=38341
  _globals['_FIVEGDUCELLMETRICSDTO']._serialized_start=38344
  _globals['_FIVEGDUCELLMETRICSDTO']._serialized_end=38661
  _globals['_FIVEGDULOWMETRICSDICT']._serialized_start=38663
  _globals['_FIVEGDULOWMETRICSDICT']._serialized_end=38736
  _globals['_FIVEGDULOWMETRICSDTO']._serialized_start=38739
  _globals['_FIVEGDULOWMETRICSDTO']._serialized_end=39087
  _globals['_FIVEGDUMETRICSDICT']._serialized_start=39089
  _globals['_FIVEGDUMETRICSDICT']._serialized_end=39156
  _globals['_FIVEGDUMETRICSDTO']._serialized_start=39159
  _globals['_FIVEGDUMETRICSDTO']._serialized_end=39318
  _globals['_FIVEGDURLCMETRICSDICT']._serialized_start=39320
  _globals['_FIVEGDURLCMETRICSDICT']._serialized_end=39393
  _globals['_FIVEGDURLCMETRICSDTO']._serialized_start=39396
  _globals['_FIVEGDURLCMETRICSDTO']._serialized_end=39769
  _globals['_CLUSTERMANAGER']._serialized_start=39773
  _globals['_CLUSTERMANAGER']._serialized_end=58154
# @@protoc_insertion_point(module_scope)
